; Do not edit this file: It was automatically generated by cmpl.pl
(setq singular-help-topics-alist
  '(
    ("!" . "Special characters.  (line  68")
    ("!=" . "boolean expressions. (line   6")
    ("\"" . "Special characters.  (line  77")
    ("\#" . "Special characters.  (line 122")
    ("$" . "Special characters.  (line 125")
    ("%" . "intvec expressions.  (line   6")
    ("&&" . "boolean operations.  (line   6")
    ("(" . "Special characters.  (line  14")
    (")" . "Special characters.  (line  14")
    ("*" . "intvec expressions.  (line   6")
    ("**" . "Special characters.  (line  46")
    ("+" . "intvec expressions.  (line   6")
    ("++" . "Special characters.  (line  26")
    ("-" . "intvec expressions.  (line   6")
    ("-allow-net" . "Command line options")
    ("-b" . "Command line options")
    ("-batch" . "Command line options")
    ("-browser" . "Command line options")
    ("-c" . "Command line options")
    ("-d" . "Command line options")
    ("-e" . "Command line options")
    ("-echo" . "Command line options")
    ("-emacs" . "Command line options")
    ("-emacs-dir" . "Command line options")
    ("-emacs-load" . "Command line options")
    ("-execute" . "Command line options")
    ("-h" . "Command line options")
    ("-help" . "Command line options")
    ("-min-time" . "Command line options")
    ("-MPhost" . "Command line options")
    ("-MPport" . "Command line options")
    ("-no-out" . "Command line options")
    ("-no-rc" . "Command line options")
    ("-no-stdlib" . "Command line options")
    ("-no-tty" . "Command line options")
    ("-no-warn" . "Command line options")
    ("-q" . "Command line options")
    ("-quiet" . "Command line options")
    ("-r" . "Command line options")
    ("-random" . "Command line options")
    ("-sdb" . "Command line options")
    ("-singular" . "Command line options")
    ("-ticks-per-sec" . "Command line options")
    ("-u" . "Command line options")
    ("-user-option" . "Command line options")
    ("-v" . "Command line options")
    ("-verbose" . "Command line options")
    (".." . "Special characters.  (line 104")
    (".singularrc file" . "Startup sequence.    (line  10")
    (".singularrc file, no loading" . "Command line options")
    ("/" . "intvec expressions.  (line   6")
    ("//" . "Special characters.  (line  86")
    (":" . "intvec expressions.  (line   6")
    ("::" . "package.             (line   6")
    (";" . "Special characters.  (line  95")
    ("<" . "filecmd.             (line   6")
    ("<=" . "boolean expressions. (line   6")
    ("<>" . "boolean expressions. (line   6")
    ("=" . "Special characters.  (line   8")
    ("==" . "boolean expressions. (line   6")
    (">" . "Special characters.  (line  58")
    (">=" . "boolean expressions. (line   6")
    ("?" . "help.                (line  19")
    ("[" . "Special characters.  (line  17")
    ("\\" . "Special characters.  (line 101")
    ("]" . "Special characters.  (line  17")
    ("^" . "ideal operations.    (line   6")
    ("_" . "Special characters.  (line 116")
    ("`" . "Special characters.  (line  80")
    ("a, ordering" . "Extra weight vector. (line   6")
    ("A_L" . "A_L.                 (line   6")
    ("A_Z" . "A_Z.                 (line   6")
    ("absfact.lib" . "absfact_lib.         (line   6")
    ("absfact_lib" . "absfact_lib.         (line   6")
    ("absFactorize" . "absFactorize.        (line   6")
    ("absolute factorization." . "absfact_lib.         (line  31")
    ("absPrimdecGTZ" . "absPrimdecGTZ.       (line   6")
    ("abstractR" . "abstractR.           (line   6")
    ("absValue" . "absValue.            (line   6")
    ("Access to elements of a user defined type" . "Access to elements of a user defined type")
    ("actionIsProper" . "actionIsProper.      (line   6")
    ("addcol" . "addcol.              (line   6")
    ("addRat" . "addRat.              (line   6")
    ("addrow" . "addrow.              (line   6")
    ("ademRelations" . "ademRelations.       (line   6")
    ("Adj_div" . "Adj_div.             (line   6")
    ("adjoint" . "adjoint.             (line   6")
    ("Adjoint ideal" . "paraplanecurves_lib. (line  73")
    ("adjointIdeal" . "adjointIdeal.        (line   6")
    ("adjunction divisor" . "Adj_div.             (line  64")
    ("admissibleSub" . "admissibleSub.       (line   6")
    ("afaces" . "afaces.              (line   6")
    ("affine code" . "Fitzgerald-Lax method")
    ("AG codes" . "AG codes.            (line   6")
    ("AGcode_L" . "AGcode_L.            (line   6")
    ("AGcode_Omega" . "AGcode_Omega.        (line   6")
    ("ainvar.lib" . "ainvar_lib.          (line   6")
    ("ainvar_lib" . "ainvar_lib.          (line   6")
    ("aksaka.lib" . "aksaka_lib.          (line   6")
    ("aksaka_lib" . "aksaka_lib.          (line   6")
    ("Alexander polynomial" . "alexpoly_lib.        (line  40")
    ("alexanderpolynomial" . "alexanderpolynomial. (line   6")
    ("alexpoly.lib" . "alexpoly_lib.        (line   6")
    ("alexpoly_lib" . "alexpoly_lib.        (line   6")
    ("alg_kernel" . "alg_kernel.          (line   6")
    ("algDependent" . "algDependent.        (line   6")
    ("algebra.lib" . "algebra_lib.         (line   6")
    ("algebra_containment" . "algebra_containment. (line   6")
    ("algebra_lib" . "algebra_lib.         (line   6")
    ("Algebraic dependence" . "Algebraic dependence")
    ("algebraic dependence" . "perron_lib.          (line  21")
    ("algebraic field extension" . "splitring.           (line  32")
    ("Algebraic geometry" . "Algebraic geometry.  (line   6")
    ("Algebraic Geometry codes" . "brnoeth_lib.         (line  43")
    ("algebraicDependence" . "algebraicDependence. (line   6")
    ("algorithm of Bigatti, La Scala and Robbiano" . "Bigatti and La Scala and Robbiano")
    ("algorithm of Conti and Traverso" . "Conti and Traverso.  (line   6")
    ("algorithm of Di Biase and Urbanke" . "Di Biase and Urbanke")
    ("algorithm of Hosten and Sturmfels" . "Hosten and Sturmfels")
    ("algorithm of Pottier" . "Pottier.             (line   6")
    ("all.lib" . "all_lib.             (line   6")
    ("all_lib" . "all_lib.             (line   6")
    ("allDoubleExt" . "allDoubleExt.        (line   6")
    ("allExtOfLeft" . "allExtOfLeft.        (line   6")
    ("allExtOfRight" . "allExtOfRight.       (line   6")
    ("allowing net access" . "Command line options")
    ("allPositive" . "allPositive.         (line   6")
    ("allprint" . "allprint.            (line   6")
    ("allreal" . "allreal.             (line   6")
    ("allrealst" . "allrealst.           (line   6")
    ("allsquarefree" . "allsquarefree.       (line   6")
    ("AltVarEnd" . "AltVarEnd.           (line   6")
    ("AltVarStart" . "AltVarStart.         (line   6")
    ("ambientDimension" . "ambientDimension.    (line   6")
    ("and" . "Evaluation of logical expressions")
    ("Ann" . "Ann.                 (line   6")
    ("annfs" . "annfs.               (line   6")
    ("annfs0" . "annfs0.              (line   6")
    ("annfs2" . "annfs2.              (line   6")
    ("annfsBMI" . "annfsBMI.            (line   6")
    ("annfsParamBM" . "annfsParamBM.        (line   6")
    ("annfspecial" . "annfspecial.         (line   6")
    ("annfsRB" . "annfsRB.             (line   6")
    ("annihilator of polynomial" . "dmodapp_lib.         (line 104")
    ("annihilator of rational function" . "dmodloc_lib.         (line  93")
    ("annil" . "annil.               (line   6")
    ("annPoly" . "annPoly.             (line   6")
    ("annRat" . "annRat.              (line   6")
    ("annRatSyz" . "annRatSyz.           (line   6")
    ("Appel function" . "dmodapp_lib.         (line 104")
    ("Appel hypergeometric function" . "dmodapp_lib.         (line 104")
    ("appelF1" . "appelF1.             (line   6")
    ("appelF2" . "appelF2.             (line   6")
    ("appelF4" . "appelF4.             (line   6")
    ("appendWeight2Ord" . "appendWeight2Ord.    (line   6")
    ("Applications" . "Applications.        (line   6")
    ("applyAdF" . "applyAdF.            (line   6")
    ("arcpoint.lib" . "arcpoint_lib.        (line   6")
    ("arcpoint_lib" . "arcpoint_lib.        (line   6")
    ("areZeroElements" . "areZeroElements.     (line   6")
    ("argument, default" . "Parameter list.      (line   6")
    ("argument, optional" . "Parameter list.      (line   6")
    ("ArnoldAction" . "ArnoldAction.        (line   6")
    ("arrange" . "arrange.             (line   6")
    ("ASCII" . "ASCII.               (line   6")
    ("ASCII links" . "ASCII links.         (line   6")
    ("ask" . "ask.                 (line   6")
    ("assignment,custom" . "Assignments for user defined types")
    ("Assignments for user defined types" . "Assignments for user defined types")
    ("assPrimes" . "assPrimes.           (line   6")
    ("assprimeszerodim.lib" . "assprimeszerodim_lib")
    ("assprimeszerodim_lib" . "assprimeszerodim_lib")
    ("Atkin" . "Atkin.               (line   6")
    ("atkins.lib" . "atkins_lib.          (line   6")
    ("atkins_lib" . "atkins_lib.          (line   6")
    ("attrib" . "attrib.              (line   6")
    ("Authors" . "Preface.             (line 144")
    ("autonom" . "autonom.             (line   6")
    ("autonomDim" . "autonomDim.          (line   6")
    ("awalk1" . "awalk1.              (line   6")
    ("awalk2" . "awalk2.              (line   6")
    ("b-function" . "bfun_lib.            (line  68")
    ("babyGiant" . "babyGiant.           (line   6")
    ("Background" . "Background.          (line   6")
    ("backward" . "backward.            (line   6")
    ("bareiss" . "bareiss.             (line   6")
    ("base2str" . "base2str.            (line   6")
    ("basering" . "def.                 (line   6")
    ("Basic programming" . "Basic programming.   (line   6")
    ("basicinvariants" . "basicinvariants.     (line   6")
    ("belongSemigroup" . "belongSemigroup.     (line   6")
    ("bernstein" . "bernstein.           (line   6")
    ("Bernstein operator" . "dmod_lib.            (line 109")
    ("Bernstein-Sato polynomial" . "bernstein.           (line  22")
    ("Bernstein-Sato polynomial for variety" . "dmodvar_lib.         (line  59")
    ("bernsteinBM" . "bernsteinBM.         (line   6")
    ("bernsteinLift" . "bernsteinLift.       (line   6")
    ("bertini2Singular" . "bertini2Singular.    (line   6")
    ("betti" . "betti.               (line   6")
    ("betti (plural)" . "betti (plural).      (line   6")
    ("Betti number" . "Syzygies and resolutions")
    ("bFactor" . "bFactor.             (line   6")
    ("bfct" . "bfct.                (line   6")
    ("bfctAnn" . "bfctAnn.             (line   6")
    ("bfctBound" . "bfctBound.           (line   6")
    ("bfctIdeal" . "bfctIdeal.           (line   6")
    ("bfctOneGB" . "bfctOneGB.           (line   6")
    ("bfctSyz" . "bfctSyz.             (line   6")
    ("bfctVarAnn" . "bfctVarAnn.          (line   6")
    ("bfctVarIn" . "bfctVarIn.           (line   6")
    ("bfun.lib" . "bfun_lib.            (line   6")
    ("bfun_lib" . "bfun_lib.            (line   6")
    ("Bigatti-La Scala-Robbiano algorithm" . "Bigatti and La Scala and Robbiano")
    ("bigint" . "bigint.              (line   6")
    ("bigint declarations" . "bigint declarations. (line   6")
    ("bigint expressions" . "bigint expressions.  (line   6")
    ("bigint operations" . "bigint operations.   (line   6")
    ("bigint related functions" . "bigint related functions")
    ("bigintmat" . "bigintmat.           (line   6")
    ("bigintmat declarations" . "bigintmat declarations")
    ("bigintmat expressions" . "bigintmat expressions")
    ("bigintmat operations" . "bigintmat operations")
    ("bigintmat type cast" . "bigintmat type cast. (line   6")
    ("binomial" . "binomial.            (line   6")
    ("binomials2intmat" . "binomials2intmat.    (line   6")
    ("BINresol" . "BINresol.            (line   6")
    ("birational map, image, inverse." . "invertBirMap.        (line  33")
    ("blackbox" . "countedref.          (line   6")
    ("block" . "Control structures.  (line   6")
    ("BlowingUp" . "BlowingUp.           (line   6")
    ("blowUp" . "blowUp.              (line   6")
    ("blowup0" . "blowup0.             (line   6")
    ("blowUp2" . "blowUp2.             (line   6")
    ("blowUpBO" . "blowUpBO.            (line   6")
    ("Blowupcenter" . "Blowupcenter.        (line   6")
    ("boolean expressions" . "boolean expressions. (line   6")
    ("boolean operations" . "boolean operations.  (line   6")
    ("boolean_constant" . "boolean_constant.    (line   6")
    ("boolean_ideal" . "boolean_ideal.       (line   6")
    ("boolean_poly" . "boolean_poly.        (line   6")
    ("boolean_poly_ring" . "boolean_poly_ring.   (line   6")
    ("boolean_set" . "boolean_set.         (line   6")
    ("boolean_std" . "boolean_std.         (line   6")
    ("BorelCheck" . "BorelCheck.          (line   6")
    ("boundaryLatticePoints" . "boundaryLatticePoints")
    ("boundBuFou" . "boundBuFou.          (line   6")
    ("boundDes" . "boundDes.            (line   6")
    ("boundposDes" . "boundposDes.         (line   6")
    ("bracket" . "bracket.             (line   6")
    ("Branches of space curve singularities" . "Branches of space curve singularities")
    ("break" . "break.               (line   6")
    ("break point" . "~.                   (line   6")
    ("breakpoint" . "breakpoint.          (line   6")
    ("Briancon-Maisonobe algorithm" . "dmod_lib.            (line 109")
    ("Brieskorn lattice" . "mondromy_lib.        (line  34")
    ("Brill-Noether algorithm" . "brnoeth_lib.         (line  43")
    ("BrillNoether" . "BrillNoether.        (line   6")
    ("brnoeth.lib" . "brnoeth_lib.         (line   6")
    ("brnoeth_lib" . "brnoeth_lib.         (line   6")
    ("browser, command line option" . "Command line options")
    ("browser, setting the" . "system.              (line  88")
    ("browsers" . "The online help system")
    ("browsers, setting the" . "system.              (line  88")
    ("bubblesort" . "bubblesort.          (line   6")
    ("Buchberger algorithm for toric ideals" . "Buchberger algorithm")
    ("Budur-Mustata-Saito approach" . "dmodvar_lib.         (line  59")
    ("bug, ESingular" . "Unix installation instructions")
    ("busadj" . "busadj.              (line   6")
    ("bvar" . "bvar.                (line   6")
    ("C programming language" . "Major differences to the C programming language")
    ("c, module ordering" . "Module orderings.    (line  49")
    ("C, module ordering" . "Module orderings.    (line  19")
    ("calculateI" . "calculateI.          (line   6")
    ("cancelunit, option" . "option.              (line 134")
    ("canonicalizeCone" . "canonicalizeCone.    (line   6")
    ("canonize" . "canonize.            (line   6")
    ("canonMap" . "canonMap.            (line   6")
    ("cantoradd" . "cantoradd.           (line   6")
    ("cantormult" . "cantormult.          (line   6")
    ("cantorred" . "cantorred.           (line   6")
    ("cardGroup" . "cardGroup.           (line   6")
    ("case" . "No case or switch statement")
    ("Castelnuovo-Mumford regularity" . "CM_regularity.       (line  21")
    ("Category string" . "Category string.     (line   6")
    ("cdd" . "Preface.             (line   6")
    ("cddlib" . "Preface.             (line   6")
    ("CenCharDec" . "CenCharDec.          (line   6")
    ("Center" . "Center.              (line   6")
    ("center" . "center.              (line   6")
    ("CenterBO" . "CenterBO.            (line   6")
    ("centerRed" . "centerRed.           (line   6")
    ("centerVS" . "centerVS.            (line   6")
    ("central.lib" . "central_lib.         (line   6")
    ("central1st" . "central1st.          (line   6")
    ("central2nd" . "central2nd.          (line   6")
    ("central_lib" . "central_lib.         (line   6")
    ("centralize" . "central_lib.         (line  19")
    ("centralizer" . "centralizer.         (line   6")
    ("centralizerRed" . "centralizerRed.      (line   6")
    ("centralizerVS" . "centralizerVS.       (line   6")
    ("centralizeSet" . "centralizeSet.       (line   6")
    ("CentralQuot" . "CentralQuot.         (line   6")
    ("CentralSaturation" . "CentralSaturation.   (line   6")
    ("cgs" . "cgs.                 (line   6")
    ("CGS, disjoint, reduced, Comprehensive Groebner System" . "cgsdr")
    ("cgsdr" . "cgsdr.               (line   6")
    ("chaincrit" . "chaincrit.           (line   6")
    ("Change of rings" . "Change of rings.     (line   6")
    ("changechar" . "changechar.          (line   6")
    ("changeDenominator" . "changeDenominator.   (line   6")
    ("changeord" . "changeord.           (line   6")
    ("changes" . "News and changes.    (line   6")
    ("changevar" . "changevar.           (line   6")
    ("char" . "char.                (line   6")
    ("char_series" . "char_series.         (line   6")
    ("characteristic exponents" . "invariants.          (line  47")
    ("Characteristic sets" . "Characteristic sets. (line   6")
    ("characteristic variety" . "dmodloc_lib.         (line  93")
    ("CharacteristicExponents" . "CharacteristicExponents")
    ("charexp2conductor" . "charexp2conductor.   (line   6")
    ("charexp2generators" . "charexp2generators.  (line   6")
    ("charexp2inter" . "charexp2inter.       (line   6")
    ("charexp2multseq" . "charexp2multseq.     (line   6")
    ("charexp2poly" . "charexp2poly.        (line   6")
    ("charInfo" . "charInfo.            (line   6")
    ("charpoly" . "charpoly.            (line   6")
    ("charstr" . "charstr.             (line   6")
    ("charVariety" . "charVariety.         (line   6")
    ("checkFactor" . "checkFactor.         (line   6")
    ("checkRoot" . "checkRoot.           (line   6")
    ("Chevalley-Rosenlicht theorem" . "tangentGens.         (line  34")
    ("chineseRem" . "chineseRem.          (line   6")
    ("chinrem" . "chinrem.             (line   6")
    ("chinrestp" . "chinrestp.           (line   6")
    ("cisimplicial.lib" . "cisimplicial_lib.    (line   6")
    ("cisimplicial_lib" . "cisimplicial_lib.    (line   6")
    ("Classification of hypersurface singularities" . "Classification of hypersurface singularities")
    ("Classification of singularities" . "realclassify.        (line  38")
    ("classify" . "classify.            (line   6")
    ("classify.lib" . "classify_lib.        (line   6")
    ("classify_lib" . "classify_lib.        (line   6")
    ("classifyCeq" . "classifyCeq.         (line   6")
    ("classifyceq.lib" . "classifyceq_lib.     (line   6")
    ("classifyceq_lib" . "classifyceq_lib.     (line   6")
    ("cleanTmp" . "cleanTmp.            (line   6")
    ("cleanunit" . "cleanunit.           (line   6")
    ("cleardenom" . "cleardenom.          (line   6")
    ("close" . "close.               (line   6")
    ("closed_points" . "closed_points.       (line   6")
    ("closetex" . "closetex.            (line   6")
    ("closureFrac" . "closureFrac.         (line   6")
    ("CM_regularity" . "CM_regularity.       (line   6")
    ("CMtype" . "CMtype.              (line   6")
    ("Code" . "Codes and the decoding problem")
    ("Codes and the decoding problem" . "Codes and the decoding problem")
    ("codim" . "codim.               (line   6")
    ("codimension" . "codimension.         (line   6")
    ("Coding theory" . "Coding theory.       (line   6")
    ("coding theory" . "AG codes.            (line   6")
    ("coef" . "coef.                (line   6")
    ("coefficient field" . "number.              (line   6")
    ("coefficient rings, ring of integers, zero divisors, p-adic numbers" . "Coefficient rings")
    ("coefficients, long" . "Long coefficients.   (line   6")
    ("coeffmod" . "coeffmod.            (line   6")
    ("coeffs" . "coeffs.              (line   6")
    ("coHom" . "coHom.               (line   6")
    ("collectDiv" . "collectDiv.          (line   6")
    ("colrank" . "colrank.             (line   6")
    ("colred" . "colred.              (line   6")
    ("comma" . "Usage of commas.     (line   6")
    ("Command line options" . "Command line options")
    ("command,custom" . "Commands for user defined types")
    ("command-line option, setting value of" . "system.              (line  88")
    ("command-line option, value of" . "system.              (line  83")
    ("command-line options, print all values of" . "system.          (line  80")
    ("command-line options, short help" . "Command line options")
    ("Commands" . "Functions and system variables")
    ("commands (plural)" . "Functions (plural).  (line   6")
    ("Commands for user defined types" . "Commands for user defined types")
    ("comment" . "Special characters.  (line  86")
    ("commRing" . "commRing.            (line   6")
    ("Commutative Algebra" . "Commutative Algebra. (line   6")
    ("completeReduction" . "completeReduction.   (line   6")
    ("complex" . "Rings and orderings. (line  26")
    ("complexSingType" . "complexSingType.     (line   6")
    ("ComplexValue" . "ComplexValue.        (line   6")
    ("compregb.lib" . "compregb_lib.        (line   6")
    ("compregb_lib" . "compregb_lib.        (line   6")
    ("comprehensive Groebner system" . "compregb_lib.        (line  27")
    ("compress" . "compress.            (line   6")
    ("computemcm" . "computemcm.          (line   6")
    ("Computing Groebner and Standard Bases" . "Computing Groebner and Standard Bases")
    ("concat" . "concat.              (line   6")
    ("conductor" . "charexp2conductor.   (line  18")
    ("conductor, degree" . "invariants.          (line  47")
    ("cone" . "cone.                (line   6")
    ("cone related functions" . "cone related functions")
    ("coneLink" . "coneLink.            (line   6")
    ("coneViaInequalities" . "coneViaInequalities. (line   6")
    ("coneViaPoints" . "coneViaPoints.       (line   6")
    ("conic, parametrization, rational point." . "paraConic.         (line  31")
    ("conicWithTangents" . "conicWithTangents.   (line   6")
    ("constructblwup" . "constructblwup.      (line   6")
    ("constructH" . "constructH.          (line   6")
    ("constructlastblwup" . "constructlastblwup.  (line   6")
    ("contact matrix" . "charexp2inter.       (line  19")
    ("ContactMatrix" . "ContactMatrix.       (line   6")
    ("containedQ" . "containedQ.          (line   6")
    ("containsAsFace" . "containsAsFace.      (line   6")
    ("containsInCollection" . "containsInCollection")
    ("containsInSupport" . "containsInSupport.   (line   6")
    ("containsPositiveVector" . "containsPositiveVector")
    ("containsRelatively" . "containsRelatively.  (line   6")
    ("content" . "content.             (line   6")
    ("contentSB, option" . "option.              (line 138")
    ("Conti-Traverso algorithm" . "Conti and Traverso.  (line   6")
    ("continue" . "Behavior of continue")
    ("contract" . "contract.            (line   6")
    ("contraHom" . "contraHom.           (line   6")
    ("contributors" . "system.              (line  56")
    ("Contributors" . "Preface.             (line 144")
    ("control" . "control.             (line   6")
    ("Control structures" . "Control structures.  (line   6")
    ("Control theory" . "System and Control Theory")
    ("control.lib" . "control_lib.         (line   6")
    ("control_lib" . "control_lib.         (line   6")
    ("control_Matrix" . "control_Matrix.      (line   6")
    ("controlDim" . "controlDim.          (line   6")
    ("controlExample" . "controlExample.      (line   6")
    ("convertdata" . "convertdata.         (line   6")
    ("convex geometry" . "convex geometry.     (line   6")
    ("convexHull" . "convexHull.          (line   6")
    ("convexIntersection" . "convexIntersection.  (line   6")
    ("convloc" . "convloc.             (line   6")
    ("Cooper philosophy" . "Cooper philosophy.   (line   6")
    ("coordinates" . "coords.              (line  19")
    ("coords" . "coords.              (line   6")
    ("copyright" . "Preface.             (line   6")
    ("corank" . "corank.              (line   6")
    ("Cornacchia" . "Cornacchia.          (line   6")
    ("CornacchiaModified" . "CornacchiaModified.  (line   6")
    ("cornerMonomials" . "cornerMonomials.     (line   6")
    ("countPoints" . "countPoints.         (line   6")
    ("cpu" . "system.              (line  33")
    ("createBO" . "createBO.            (line   6")
    ("createGradedRingHomomorphism" . "createGradedRingHomomorphism")
    ("createGroup" . "createGroup.         (line   6")
    ("createlist" . "createlist.          (line   6")
    ("createQuotientGroup" . "createQuotientGroup. (line   6")
    ("createTorsionFreeGroup" . "createTorsionFreeGroup")
    ("CRHT-ideal" . "Cooper philosophy.   (line  25")
    ("Critical points" . "Critical points.     (line   6")
    ("crypto.lib" . "crypto_lib.          (line   6")
    ("crypto_lib" . "crypto_lib.          (line   6")
    ("cup" . "cup.                 (line   6")
    ("cupproduct" . "cupproduct.          (line   6")
    ("curve singularities" . "hnoether_lib.        (line  49")
    ("curvepar.lib" . "curvepar_lib.        (line   6")
    ("curvepar_lib" . "curvepar_lib.        (line   6")
    ("CurveParam" . "CurveParam.          (line   6")
    ("CurveRes" . "CurveRes.            (line   6")
    ("Curves" . "paraplanecurves_lib. (line  73")
    ("custom assignment" . "Assignments for user defined types")
    ("custom command" . "Commands for user defined types")
    ("custom type" . "Definition of a user defined type")
    ("Customization of the Emacs interface" . "Customization of the Emacs interface")
    ("cycleLength" . "cycleLength.         (line   6")
    ("cyclePoints" . "cyclePoints.         (line   6")
    ("cyclic" . "cyclic.              (line   6")
    ("Cyclic code" . "decodegb_lib.        (line  50")
    ("cyclic code" . "Codes and the decoding problem")
    ("Cyclic roots" . "Cyclic roots.        (line   6")
    ("cyclotomic" . "cyclotomic.          (line   6")
    ("D-integration" . "dmodapp_lib.         (line 104")
    ("D-localization" . "dmodloc_lib.         (line  93")
    ("D-module" . "dmodloc_lib.         (line  93")
    ("D-module structure" . "dmodvar_lib.         (line  59")
    ("D-restriction" . "dmodapp_lib.         (line 104")
    ("Data types" . "Data types.          (line   6")
    ("Data types (plural)" . "Data types (plural). (line   6")
    ("datetime" . "datetime.            (line   6")
    ("DBM links" . "DBM links.           (line   6")
    ("dbprint" . "dbprint.             (line   6")
    ("debug_log" . "debug_log.           (line   6")
    ("debugger" . "Source code debugger")
    ("debugging library code" . "Source code debugger")
    ("Debugging tools" . "Debugging tools.     (line   6")
    ("debugLib, option" . "option.              (line 169")
    ("dec1var" . "dec1var.             (line   6")
    ("decimal" . "decimal.             (line   6")
    ("Decker, Wolfram" . "Preface.             (line 144")
    ("Declaration of objects of a user defined type" . "Declaration of objects of a user defined type")
    ("decode" . "decode.              (line   6")
    ("decodeCode" . "decodeCode.          (line   6")
    ("decodegb.lib" . "decodegb_lib.        (line   6")
    ("decodegb_lib" . "decodegb_lib.        (line   6")
    ("decodeRandom" . "decodeRandom.        (line   6")
    ("decodeRandomFL" . "decodeRandomFL.      (line   6")
    ("decodeSV" . "decodeSV.            (line   6")
    ("Decoding" . "decodegb_lib.        (line  50")
    ("Decoding codes with Groebner bases" . "Decoding codes with Groebner bases")
    ("Decoding method based on quadratic equations" . "Decoding method based on quadratic equations")
    ("decoding, decoding problem" . "Codes and the decoding problem")
    ("decoef" . "decoef.              (line   6")
    ("def" . "def.                 (line   6")
    ("def declarations" . "def declarations.    (line   6")
    ("default argument" . "Parameter list.      (line   6")
    ("defined" . "defined.             (line   6")
    ("defineHomogeneous" . "defineHomogeneous.   (line   6")
    ("Definition of a user defined type" . "Definition of a user defined type")
    ("defl" . "defl.                (line   6")
    ("deform" . "deform.              (line   6")
    ("deform.lib" . "deform_lib.          (line   6")
    ("deform_lib" . "deform_lib.          (line   6")
    ("Deformations" . "Deformations.        (line   6")
    ("Deformations, T1 and T2" . "T1 and T2.           (line   6")
    ("defRes, option" . "option.              (line 172")
    ("defring" . "defring.             (line   6")
    ("defringp" . "defringp.            (line   6")
    ("defrings" . "defrings.            (line   6")
    ("deg" . "deg.                 (line   6")
    ("degBound" . "degBound.            (line   6")
    ("Degree" . "Degree.              (line   6")
    ("degree" . "Miscellaneous oddities")
    ("degree lexicographical ordering" . "Global orderings.    (line  28")
    ("degree of a polynomial" . "Miscellaneous oddities")
    ("degree reverse lexicographical ordering" . "Global orderings.  (line  19")
    ("degreeDivisor" . "degreeDivisor.       (line   6")
    ("degreeFormalDivisor" . "degreeFormalDivisor. (line   6")
    ("degreepart" . "degreepart.          (line   6")
    ("delete" . "delete.              (line   6")
    ("deleteGenerator" . "deleteGenerator.     (line   6")
    ("deleteSublist" . "deleteSublist.       (line   6")
    ("delta" . "delta.               (line   6")
    ("Delta" . "Delta.               (line   6")
    ("delta invariant" . "delta.               (line  25")
    ("delta invariant." . "normalC.             (line  99")
    ("DeltaList" . "DeltaList.           (line   6")
    ("deltaLoc" . "deltaLoc.            (line   6")
    ("Demo mode" . "Demo mode.           (line   6")
    ("denominator" . "denominator.         (line   6")
    ("depth" . "depth.               (line   6")
    ("Depth" . "Depth.               (line   6")
    ("depthIdeal" . "depthIdeal.          (line   6")
    ("derham.lib" . "derham_lib.          (line   9")
    ("derham_lib" . "derham_lib.          (line   9")
    ("deRhamCohom" . "deRhamCohom.         (line   6")
    ("deRhamCohomIdeal" . "deRhamCohomIdeal.    (line   6")
    ("deRhamCohomology" . "deRhamCohomology.    (line   6")
    ("derivate" . "derivate.            (line   6")
    ("det" . "det.                 (line   6")
    ("det_B" . "det_B.               (line   6")
    ("detadj" . "detadj.              (line   6")
    ("Determinacy" . "determinacy.         (line  21")
    ("determinacy" . "determinacy.         (line   6")
    ("determinecenter" . "determinecenter.     (line   6")
    ("detropicalise" . "detropicalise.       (line   6")
    ("develop" . "develop.             (line   6")
    ("Di Biase-Urbanke algorithm" . "Di Biase and Urbanke")
    ("diag" . "diag.                (line   6")
    ("diag_test" . "diag_test.           (line   6")
    ("diagInvariants" . "diagInvariants.      (line   6")
    ("diff" . "diff.                (line   6")
    ("diffRat" . "diffRat.             (line   6")
    ("difpoly2tex" . "difpoly2tex.         (line   6")
    ("dim" . "dim.                 (line   6")
    ("dim (plural)" . "dim (plural).        (line   6")
    ("dim_slocus" . "dim_slocus.          (line   6")
    ("dimension" . "dimension.           (line   6")
    ("dimGradedPart" . "dimGradedPart.       (line   6")
    ("dimH" . "dimH.                (line   6")
    ("dimMon" . "dimMon.              (line   6")
    ("direct_boolean_poly" . "direct_boolean_poly. (line   6")
    ("direct_from_boolean_poly" . "direct_from_boolean_poly")
    ("disc" . "disc.                (line   6")
    ("discr" . "discr.               (line   6")
    ("discrepancy" . "discrepancy.         (line   6")
    ("disp_zdd" . "disp_zdd.            (line   6")
    ("DISPLAY environment variable" . "The online help system")
    ("displayCohom" . "displayCohom.        (line   6")
    ("displayHNE" . "displayHNE.          (line   6")
    ("displayInvariants" . "displayInvariants.   (line   6")
    ("displayMultsequence" . "displayMultsequence. (line   6")
    ("displayPuiseuxExpansion" . "displayPuiseuxExpansion")
    ("displayTropicalLifting" . "displayTropicalLifting")
    ("Distributed computing" . "parallelWaitAll.     (line  23")
    ("div" . "Miscellaneous oddities")
    ("dividelist" . "dividelist.          (line   6")
    ("divideUnits" . "divideUnits.         (line   6")
    ("division" . "division.            (line   6")
    ("division (plural)" . "division (plural).   (line   6")
    ("division, pdivi, reduce" . "pnormalf.            (line  24")
    ("division, reduce" . "pdivi.               (line  23")
    ("divisor" . "divisor.             (line   6")
    ("divisorplus" . "divisorplus.         (line   6")
    ("divisors" . "degreeFormalDivisor. (line  19")
    ("divisors, polyhedra" . "pdivisorplus.        (line  20")
    ("divisors.lib" . "divisors_lib.        (line   6")
    ("divisors_lib" . "divisors_lib.        (line   6")
    ("DLoc" . "DLoc.                (line   6")
    ("DLoc0" . "DLoc0.               (line   6")
    ("Dlocalization" . "Dlocalization.       (line   6")
    ("dmod.lib" . "dmod_lib.            (line   6")
    ("dmod_lib" . "dmod_lib.            (line   6")
    ("dmodAction" . "dmodAction.          (line   6")
    ("dmodActionRat" . "dmodActionRat.       (line   6")
    ("dmodapp.lib" . "dmodapp_lib.         (line   6")
    ("dmodapp_lib" . "dmodapp_lib.         (line   6")
    ("dmodGeneralAssumptionCheck" . "dmodGeneralAssumptionCheck")
    ("dmodloc.lib" . "dmodloc_lib.         (line   6")
    ("dmodloc_lib" . "dmodloc_lib.         (line   6")
    ("dmodoublext" . "dmodoublext.         (line   6")
    ("dmodvar.lib" . "dmodvar_lib.         (line   6")
    ("dmodvar_lib" . "dmodvar_lib.         (line   6")
    ("Documentation Tool" . "Documentation Tool.  (line   6")
    ("double" . "double.              (line   6")
    ("doubleExt" . "doubleExt.           (line   6")
    ("downloading" . "Download instructions")
    ("Dp, global ordering" . "Global orderings.    (line  28")
    ("dp, global ordering" . "Global orderings.    (line  19")
    ("drawNewtonSubdivision" . "drawNewtonSubdivision")
    ("drawTropicalCurve" . "drawTropicalCurve.   (line   6")
    ("Ds, local ordering" . "Local orderings.     (line  25")
    ("ds, local ordering" . "Local orderings.     (line  16")
    ("DsingularLocus" . "DsingularLocus.      (line   6")
    ("dsum" . "dsum.                (line   6")
    ("dual_code" . "dual_code.           (line   6")
    ("dualCone" . "dualCone.            (line   6")
    ("dualConic" . "dualConic.           (line   6")
    ("dualPolytope" . "dualPolytope.        (line   6")
    ("dump" . "dump.                (line   6")
    ("Dynamic loading" . "Dynamic loading.     (line   6")
    ("Dynamic modules" . "Dynamic modules.     (line   6")
    ("ecart" . "ecart.               (line   6")
    ("echo" . "echo.                (line   6")
    ("ECoef" . "ECoef.               (line   6")
    ("ECPP" . "ECPP.                (line   6")
    ("Edatalist" . "Edatalist.           (line   6")
    ("Editing input" . "Editing input.       (line   6")
    ("Editing SINGULAR input files with Emacs" . "Editing SINGULAR input files with Emacs")
    ("eexgcdN" . "eexgcdN.             (line   6")
    ("effective" . "effective.           (line   6")
    ("egcdMain" . "egcdMain.            (line   6")
    ("ehrhartPolynomialCoeff" . "ehrhartPolynomialCoeff")
    ("ehrhartRing" . "ehrhartRing.         (line   6")
    ("eigenvals" . "eigenvals.           (line   6")
    ("eigenvalues" . "eigenvalues.         (line   6")
    ("elemSymmId" . "elemSymmId.          (line   6")
    ("elim" . "elim.                (line   6")
    ("elim.lib" . "elim_lib.            (line   6")
    ("elim1" . "elim1.               (line   6")
    ("elim2" . "elim2.               (line   6")
    ("elim_lib" . "elim_lib.            (line   6")
    ("eliminate" . "eliminate.           (line   6")
    ("eliminate (plural)" . "eliminate (plural).  (line   6")
    ("eliminateNC" . "eliminateNC.         (line   6")
    ("Elimination" . "Elimination.         (line   6")
    ("elimination" . "ncpreim_lib.         (line  62")
    ("elimlinearpart" . "elimlinearpart.      (line   6")
    ("elimpart" . "elimpart.            (line   6")
    ("elimpartanyr" . "elimpartanyr.        (line   6")
    ("elimrep" . "elimrep.             (line   6")
    ("elimRing" . "elimRing.            (line   6")
    ("elimWeight" . "elimWeight.          (line   6")
    ("ellipticAdd" . "ellipticAdd.         (line   6")
    ("ellipticAllPoints" . "ellipticAllPoints.   (line   6")
    ("ellipticMult" . "ellipticMult.        (line   6")
    ("ellipticNF" . "ellipticNF.          (line   6")
    ("ellipticNFDB" . "ellipticNFDB.        (line   6")
    ("ellipticRandomCurve" . "ellipticRandomCurve. (line   6")
    ("ellipticRandomPoint" . "ellipticRandomPoint. (line   6")
    ("else" . "if.                  (line   6")
    ("Emacs" . "Emacs user interface")
    ("Emacs, a quick guide" . "A quick guide to Emacs")
    ("Emacs, customization of Singular mode" . "Customization of the Emacs interface")
    ("Emacs, editing Singular input files" . "Editing SINGULAR input files with Emacs")
    ("Emacs, important commands" . "Top 20 Emacs commands")
    ("Emacs, overview" . "A quick guide to Emacs")
    ("Emacs, running Singular under" . "Running SINGULAR under Emacs")
    ("Emacs, Singular demo mode" . "Demo mode.           (line   6")
    ("Emacs, user interface" . "Emacs user interface")
    ("Emaxcont" . "Emaxcont.            (line   6")
    ("embedMat" . "embedMat.            (line   6")
    ("emptyFan" . "emptyFan.            (line   6")
    ("encode" . "encode.              (line   6")
    ("endomorphism filtration" . "endvfilt.            (line  25")
    ("endvfilt" . "endvfilt.            (line   6")
    ("engine" . "engine.              (line   6")
    ("envelope" . "envelope.            (line   6")
    ("environment variable, DISPLAY" . "The online help system")
    ("EOrdlist" . "EOrdlist.            (line   6")
    ("Equal" . "Equal.               (line   6")
    ("equalJinI" . "equalJinI.           (line   6")
    ("equalMultiDeg" . "equalMultiDeg.       (line   6")
    ("equations" . "equations.           (line   6")
    ("equidim" . "equidim.             (line   6")
    ("equidimMax" . "equidimMax.          (line   6")
    ("equidimMaxEHV" . "equidimMaxEHV.       (line   6")
    ("equidimZ" . "equidimZ.            (line   6")
    ("equiRadical" . "equiRadical.         (line   6")
    ("equising.lib" . "equising_lib.        (line   6")
    ("equising_lib" . "equising_lib.        (line   6")
    ("equisingular Tjurina number" . "alexpoly_lib.        (line  40")
    ("equisingularity ideal" . "esIdeal.             (line  33")
    ("equisingularity stratum" . "esStratum.           (line  43")
    ("Eresol" . "Eresol.              (line   6")
    ("ERROR" . "ERROR.               (line   6")
    ("error recovery" . "The SINGULAR prompt. (line   6")
    ("errorInsert" . "errorInsert.         (line   6")
    ("errormap" . "errormap.            (line   6")
    ("errorRand" . "errorRand.           (line   6")
    ("esIdeal" . "esIdeal.             (line   6")
    ("ESingular, no prompt" . "Unix installation instructions")
    ("esStratum" . "esStratum.           (line   6")
    ("eta" . "eta.                 (line   6")
    ("euler" . "euler.               (line   6")
    ("eval" . "eval.                (line   6")
    ("evaluate_reynolds" . "evaluate_reynolds.   (line   6")
    ("evaluateFormalDivisor" . "evaluateFormalDivisor")
    ("evaluatePDivisor" . "evaluatePDivisor.    (line   6")
    ("Evaluation of logical expressions" . "Evaluation of logical expressions")
    ("example" . "example.             (line   6")
    ("Examples" . "Examples.            (line   6")
    ("Examples of ring declarations" . "Examples of ring declarations")
    ("execute" . "execute.             (line   6")
    ("exgcdN" . "exgcdN.              (line   6")
    ("exit" . "quit.                (line   6")
    ("Exp for matrices" . "matrixExp.           (line  22")
    ("exp2pt" . "exp2pt.              (line   6")
    ("Experimental libraries" . "Experimental libraries")
    ("expo" . "expo.                (line   6")
    ("export" . "export.              (line   6")
    ("exportNuminvs" . "exportNuminvs.       (line   6")
    ("exportto" . "exportto.            (line   6")
    ("expression list" . "Data types (plural). (line   6")
    ("Ext" . "Ext.                 (line   6")
    ("Ext, computation of" . "Computation of Ext.  (line   6")
    ("ext-module" . "purityfiltration_lib")
    ("Ext_R" . "Ext_R.               (line   6")
    ("extcurve" . "extcurve.            (line   6")
    ("extdevelop" . "extdevelop.          (line   6")
    ("extend" . "extend.              (line   6")
    ("extendedTensor" . "extendedTensor.      (line   6")
    ("extendring" . "extendring.          (line   6")
    ("extendWeyl" . "extendWeyl.          (line   6")
    ("extension of rings" . "splitring.           (line  32")
    ("Exterior" . "Exterior.            (line   6")
    ("exterior basis" . "exteriorBasis.       (line  18")
    ("exterior power" . "exteriorPower.       (line  18")
    ("exteriorBasis" . "exteriorBasis.       (line   6")
    ("exteriorPower" . "exteriorPower.       (line   6")
    ("extgcd" . "extgcd.              (line   6")
    ("Extra weight vector" . "Extra weight vector. (line   6")
    ("facets" . "facets.              (line   6")
    ("facetVertexLatticeDistances" . "facetVertexLatticeDistances")
    ("facetWidth" . "facetWidth.          (line   6")
    ("facetWidths" . "facetWidths.         (line   6")
    ("facFirstShift" . "facFirstShift.       (line   6")
    ("facFirstWeyl" . "facFirstWeyl.        (line   6")
    ("facGBIdeal" . "facGBIdeal.          (line   6")
    ("facstd" . "facstd.              (line   6")
    ("facSubWeyl" . "facSubWeyl.          (line   6")
    ("factmodd" . "factmodd.            (line   6")
    ("factorgroup" . "factorgroup.         (line   6")
    ("factorH" . "factorH.             (line   6")
    ("factorial" . "factorial.           (line   6")
    ("factorization" . "absfact_lib.         (line  31")
    ("Factorization" . "Factorization.       (line   6")
    ("factorize" . "factorize.           (line   6")
    ("factorLenstraECM" . "factorLenstraECM.    (line   6")
    ("factorMain" . "factorMain.          (line   6")
    ("factory" . "Preface.             (line   6")
    ("fan" . "oldpolymake_lib.     (line  69")
    ("fan related functions" . "fan related functions")
    ("fanViaCones" . "fanViaCones.         (line   6")
    ("farey" . "farey.               (line   6")
    ("fastelim" . "fastelim.            (line   6")
    ("fastExpt" . "fastExpt.            (line   6")
    ("fastHC, option" . "option.              (line  57")
    ("fetch" . "fetch.               (line   6")
    ("fetch (plural)" . "fetch (plural).      (line   6")
    ("fetchall" . "fetchall.            (line   6")
    ("ffsolve" . "ffsolve.             (line   6")
    ("ffsolve.lib" . "ffsolve_lib.         (line   6")
    ("ffsolve_lib" . "ffsolve_lib.         (line   6")
    ("fglm" . "stdfglm.             (line  23")
    ("fglm_solve" . "fglm_solve.          (line   6")
    ("fglmquot" . "fglmquot.            (line   6")
    ("fibonacci" . "fibonacci.           (line   6")
    ("field" . "number.              (line   6")
    ("file, .singularrc" . "Startup sequence.    (line  10")
    ("filecmd" . "filecmd.             (line   6")
    ("filtration" . "purityfiltration_lib")
    ("finalCharts" . "finalCharts.         (line   6")
    ("find" . "find.                (line   6")
    ("findAuto" . "findAuto.            (line   6")
    ("findifs.lib" . "findifs_lib.         (line   6")
    ("findifs_example" . "findifs_example.     (line   6")
    ("findifs_lib" . "findifs_lib.         (line   6")
    ("findimAlgebra" . "findimAlgebra.       (line   6")
    ("findInvo" . "findInvo.            (line   6")
    ("findInvoDiag" . "findInvoDiag.        (line   6")
    ("findOrientedBoundary" . "findOrientedBoundary")
    ("findTorsion" . "findTorsion.         (line   6")
    ("finduni" . "finduni.             (line   6")
    ("findvars" . "findvars.            (line   6")
    ("finite field" . "ffsolve_lib.         (line  15")
    ("Finite fields" . "Finite fields.       (line   6")
    ("finiteDiagInvariants" . "finiteDiagInvariants")
    ("finitediff.lib" . "finitediff_lib.      (line  22")
    ("finitediff_lib" . "finitediff_lib.      (line  22")
    ("finitenessTest" . "finitenessTest.      (line   6")
    ("finvar.lib" . "finvar_lib.          (line   6")
    ("finvar_lib" . "finvar_lib.          (line   6")
    ("first index is 1" . "First index is 1.    (line   6")
    ("First steps" . "First steps.         (line   6")
    ("firstoct" . "firstoct.            (line   6")
    ("fitting" . "fitting.             (line   6")
    ("Fitzgerald-Lax method" . "Fitzgerald-Lax method")
    ("fl2poly" . "fl2poly.             (line   6")
    ("flatten" . "flatten.             (line   6")
    ("flatteningStrat" . "flatteningStrat.     (line   6")
    ("Flow control" . "Flow control.        (line   6")
    ("for" . "for.                 (line   6")
    ("Formal Checker" . "Formal Checker.      (line   6")
    ("formaldivisorplus" . "formaldivisorplus.   (line   6")
    ("Formatting output" . "Formatting output.   (line   6")
    ("forward" . "forward.             (line   6")
    ("fourier" . "fourier.             (line   6")
    ("fouriersystem" . "fouriersystem.       (line   6")
    ("fpadim.lib" . "fpadim_lib.          (line   6")
    ("fpadim_lib" . "fpadim_lib.          (line   6")
    ("fprintf" . "fprintf.             (line   6")
    ("free associative algebra, tensor algebra" . "Free associative algebras")
    ("Free resolution" . "Free resolution.     (line   6")
    ("Free resolution, graded" . "Handling graded modules")
    ("freegb.lib" . "freegb_lib.          (line   6")
    ("freegb_lib" . "freegb_lib.          (line   6")
    ("freeGBasis" . "freeGBasis.          (line   6")
    ("freemodule" . "freemodule.          (line   6")
    ("freerank" . "freerank.            (line   6")
    ("from_boolean_constant" . "from_boolean_constant")
    ("from_boolean_ideal" . "from_boolean_ideal.  (line   6")
    ("from_boolean_poly" . "from_boolean_poly.   (line   6")
    ("from_boolean_set" . "from_boolean_set.    (line   6")
    ("frwalk" . "frwalk.              (line   6")
    ("fullFan" . "fullFan.             (line   6")
    ("fullSerreRelations" . "fullSerreRelations.  (line   6")
    ("Functions" . "Functions.           (line   6")
    ("further_hn_proc" . "further_hn_proc.     (line   6")
    ("furtherInvar" . "furtherInvar.        (line   6")
    ("fVector" . "fVector.             (line   6")
    ("fVector(polymake)" . "fVector(polymake).   (line   6")
    ("fwalk" . "fwalk.               (line   6")
    ("G-algebra" . "G-algebras.          (line   6")
    ("G-algebra, setup" . "G-algebras.          (line  51")
    ("G_a -Invariants" . "G_a -Invariants.     (line   6")
    ("galois field" . "number.              (line   6")
    ("Gamma" . "Gamma.               (line   6")
    ("Gauss-Manin connection" . "spectrumnd.          (line  26")
    ("Gauss-Manin system" . "goodBasis.           (line  22")
    ("gauss_col" . "gauss_col.           (line   6")
    ("gauss_nf" . "gauss_nf.            (line   6")
    ("gauss_row" . "gauss_row.           (line   6")
    ("gaussred" . "gaussred.            (line   6")
    ("gaussred_pivot" . "gaussred_pivot.      (line   6")
    ("GBsolve" . "GBsolve.             (line   6")
    ("GBWeight" . "GBWeight.            (line   6")
    ("gcd" . "gcd.                 (line   6")
    ("gcddivisor" . "gcddivisor.          (line   6")
    ("gcdMon" . "gcdMon.              (line   6")
    ("gcdN" . "gcdN.                (line   6")
    ("gen" . "gen.                 (line   6")
    ("General command syntax" . "General command syntax")
    ("General concepts" . "General concepts.    (line   6")
    ("general error-locator polynomial" . "Cooper philosophy.   (line  46")
    ("General purpose" . "General purpose.     (line   6")
    ("General syntax of a ring declaration" . "General syntax of a ring declaration")
    ("general weighted lexicographical ordering" . "Local orderings. (line  39")
    ("general weighted reverse lexicographical ordering" . "Local orderings")
    ("general.lib" . "general_lib.         (line   6")
    ("general_lib" . "general_lib.         (line   6")
    ("Generalized Hilbert Syzygy Theorem" . "Syzygies and resolutions (plural)")
    ("Generalized Newton identities" . "Generalized Newton identities")
    ("generalOrder" . "generalOrder.        (line   6")
    ("generateG" . "generateG.           (line   6")
    ("generators" . "charexp2generators.  (line  19")
    ("generatorsOfLinealitySpace" . "generatorsOfLinealitySpace")
    ("generatorsOfSpan" . "generatorsOfSpan.    (line   6")
    ("genericid" . "genericid.           (line   6")
    ("genericity" . "genericity.          (line   6")
    ("genericmat" . "genericmat.          (line   6")
    ("genMDSMat" . "genMDSMat.           (line   6")
    ("genoutput" . "genoutput.           (line   6")
    ("genSymId" . "genSymId.            (line   6")
    ("genus" . "genus.               (line   6")
    ("Geometric genus" . "paraplanecurves_lib. (line  73")
    ("geometric invariant theory" . "gitfan_lib.          (line  24")
    ("German Umlaute" . "Limitations.         (line  53")
    ("getCone" . "getCone.             (line   6")
    ("getdump" . "getdump.             (line   6")
    ("getenv" . "system.              (line  41")
    ("getGradingGroup" . "getGradingGroup.     (line   6")
    ("getLattice" . "getLattice.          (line   6")
    ("getLinearForms" . "getLinearForms.      (line   6")
    ("getModuleGrading" . "getModuleGrading.    (line   6")
    ("getMultiplicity" . "getMultiplicity.     (line   6")
    ("getOneVar" . "getOneVar.           (line   6")
    ("getSmallest" . "getSmallest.         (line   6")
    ("Getting started" . "Getting started.     (line   6")
    ("getVariableWeights" . "getVariableWeights.  (line   6")
    ("gfanlib" . "Preface.             (line   6")
    ("GIT" . "gitfan_lib.          (line  24")
    ("gitCone" . "gitCone.             (line   6")
    ("gitFan" . "gitFan.              (line   6")
    ("gitfan" . "gitfan_lib.          (line  24")
    ("gitfan.lib" . "gitfan_lib.          (line   6")
    ("gitfan_lib" . "gitfan_lib.          (line   6")
    ("GKdim" . "GKdim.               (line   6")
    ("gkdim.lib" . "gkdim_lib.           (line   6")
    ("gkdim_lib" . "gkdim_lib.           (line   6")
    ("gkzFan" . "gkzFan.              (line   6")
    ("GKZsystem" . "GKZsystem.           (line   6")
    ("global Bernstein-Sato polynomial" . "dmod_lib.            (line 109")
    ("global Bernstein-Sato polynomial for variety" . "dmodvar_lib.  (line  59")
    ("Global orderings" . "Global orderings.    (line   6")
    ("globalSections" . "globalSections.      (line   6")
    ("GMP" . "Preface.             (line   6")
    ("gmscoeffs" . "gmscoeffs.           (line   6")
    ("gmsnf" . "gmsnf.               (line   6")
    ("gmspoly.lib" . "gmspoly_lib.         (line   6")
    ("gmspoly_lib" . "gmspoly_lib.         (line   6")
    ("gmsring" . "gmsring.             (line   6")
    ("gmssing.lib" . "gmssing_lib.         (line   6")
    ("gmssing_lib" . "gmssing_lib.         (line   6")
    ("good basis" . "goodBasis.           (line  22")
    ("goodBasis" . "goodBasis.           (line   6")
    ("gorensteinIndex" . "gorensteinIndex.     (line   6")
    ("gorensteinVector" . "gorensteinVector.    (line   6")
    ("Graded commutative algebras" . "Graded commutative algebras (SCA)")
    ("graded module, graded piece" . "dimGradedPart.       (line  22")
    ("graded modules, handling of" . "Handling graded modules")
    ("graded Weyl algebra" . "bfun_lib.            (line  68")
    ("gradeNumber" . "gradeNumber.         (line   6")
    ("gradiator" . "gradiator.           (line   6")
    ("graphics.lib" . "graphics_lib.        (line   6")
    ("graphics_lib" . "graphics_lib.        (line   6")
    ("graphviz" . "Preface.             (line   6")
    ("graver4ti2" . "graver4ti2.          (line   6")
    ("Greuel, Gert-Martin" . "Preface.             (line 144")
    ("grobcov" . "grobcov.             (line   6")
    ("grobcov.lib" . "grobcov_lib.         (line   6")
    ("grobcov_lib" . "grobcov_lib.         (line   6")
    ("groebner" . "groebner and std.    (line   6")
    ("Groebner Bases" . "Computing Groebner and Standard Bases")
    ("Groebner bases in free associative algebras" . "Groebner bases for two-sided ideals in free associative algebras")
    ("Groebner bases in G-algebras" . "Groebner bases in G-algebras")
    ("Groebner bases, decodeGB" . "decodegb_lib.        (line  50")
    ("Groebner bases, slim" . "slim Groebner bases. (line   6")
    ("Groebner basis conversion" . "Groebner basis conversion")
    ("Groebner cover, parametric ideal, canonical, discussion of" . "extend")
    ("Groebner fan" . "oldpolymake_lib.     (line  69")
    ("Groebner walk" . "gwalk.               (line  21")
    ("groebnerFan" . "groebnerFan.         (line   6")
    ("ground field" . "number.              (line   6")
    ("group_reynolds" . "group_reynolds.      (line   6")
    ("grwalk.lib" . "grwalk_lib.          (line   6")
    ("grwalk_lib" . "grwalk_lib.          (line   6")
    ("GTZmod" . "GTZmod.              (line   6")
    ("GTZopt" . "GTZopt.              (line   6")
    ("gwalk" . "gwalk.               (line   6")
    ("Gweights" . "Gweights.            (line   6")
    ("H2basis" . "H2basis.             (line   6")
    ("Hamburger-Noether expansion" . "hnoether_lib.        (line  49")
    ("Hamburger-Noether expansions" . "Adj_div.             (line  64")
    ("Handling graded modules" . "Handling graded modules")
    ("hardware platform" . "system.              (line  37")
    ("Hcode" . "Hcode.               (line   6")
    ("headStand" . "headStand.           (line   6")
    ("heightZ" . "heightZ.             (line   6")
    ("help" . "help.                (line   6")
    ("help browsers" . "The online help system")
    ("help browsers, dummy" . "The online help system")
    ("help browsers, emacs" . "The online help system")
    ("help browsers, html" . "The online help system")
    ("help browsers, setting command to use" . "The online help system")
    ("help browsers, setting the" . "system.              (line  88")
    ("Help string" . "Help string.         (line   6")
    ("help, accessing over the net" . "Command line options")
    ("help, online help system" . "The online help system")
    ("hermiteNormalForm" . "hermiteNormalForm.   (line   6")
    ("hessenberg" . "hessenberg.          (line   6")
    ("highcorner" . "highcorner.          (line   6")
    ("hilb" . "hilb.                (line   6")
    ("Hilbert function" . "Hilbert function.    (line   6")
    ("Hilbert series" . "Hilbert function.    (line   6")
    ("Hilbert-driven GB algorithm" . "Groebner basis conversion")
    ("hilbert4ti2" . "hilbert4ti2.         (line   6")
    ("hilbertBasis" . "hilbertBasis.        (line   6")
    ("HilbertClassPoly" . "HilbertClassPoly.    (line   6")
    ("hilbertSeries" . "hilbertSeries.       (line   6")
    ("HilbertSeries" . "HilbertSeries.       (line   6")
    ("HilbertWeights" . "HilbertWeights.      (line   6")
    ("hilbPoly" . "hilbPoly.            (line   6")
    ("hilbvec" . "hilbvec.             (line   6")
    ("hnexpansion" . "hnexpansion.         (line   6")
    ("hnoether.lib" . "hnoether_lib.        (line   6")
    ("hnoether_lib" . "hnoether_lib.        (line   6")
    ("holonomic rank" . "dmodloc_lib.         (line  93")
    ("holonomicRank" . "holonomicRank.       (line   6")
    ("Hom" . "Hom.                 (line   6")
    ("hom_kernel" . "hom_kernel.          (line   6")
    ("HomJJ" . "HomJJ.               (line   6")
    ("homog" . "homog.               (line   6")
    ("homogfacFirstQWeyl" . "homogfacFirstQWeyl.  (line   6")
    ("homogfacFirstQWeyl_all" . "homogfacFirstQWeyl_all")
    ("homolog.lib" . "homolog_lib.         (line   6")
    ("homolog_lib" . "homolog_lib.         (line   6")
    ("homology" . "homology.            (line   6")
    ("Hosten-Sturmfels algorithm" . "Hosten and Sturmfels")
    ("How to enter and exit" . "How to enter and exit")
    ("How to use this manual" . "How to use this manual")
    ("howto, download" . "Download instructions")
    ("howto, install on Macintosh" . "Macintosh installation instructions")
    ("howto, install on Unix" . "Unix installation instructions")
    ("howto, install on Windows" . "Windows installation instructions")
    ("hres" . "hres.                (line   6")
    ("hStarVector" . "hStarVector.         (line   6")
    ("html, default help" . "The online help system")
    ("hVector" . "hVector.             (line   6")
    ("hyperel.lib" . "hyperel_lib.         (line   6")
    ("hyperel_lib" . "hyperel_lib.         (line   6")
    ("hyperplane arrangement" . "dmod_lib.            (line 109")
    ("Hypersurface singularities, classification of" . "Classification of hypersurface singularities")
    ("hypersurface singularity" . "mondromy_lib.        (line  34")
    ("id2mod" . "id2mod.              (line   6")
    ("ideal" . "ideal.               (line   6")
    ("ideal declarations" . "ideal declarations.  (line   6")
    ("ideal declarations (plural)" . "ideal declarations (plural)")
    ("ideal expressions" . "ideal expressions.   (line   6")
    ("ideal expressions (plural)" . "ideal expressions (plural)")
    ("Ideal membership" . "Standard bases.      (line  26")
    ("ideal operations" . "ideal operations.    (line   6")
    ("ideal operations (plural)" . "ideal operations (plural)")
    ("ideal related functions" . "ideal related functions")
    ("ideal related functions (plural)" . "ideal related functions (plural)")
    ("ideal, toric" . "Toric ideals.        (line   6")
    ("ideals" . "Miscellaneous oddities")
    ("idealsimplify" . "idealsimplify.       (line   6")
    ("idealSplit" . "idealSplit.          (line   6")
    ("identifier" . "Identifier resolution")
    ("Identifiers, syntax of" . "Names.               (line   6")
    ("identifyvar" . "identifyvar.         (line   6")
    ("if" . "if.                  (line   6")
    ("image_of_variety" . "image_of_variety.    (line   6")
    ("ImageGroup" . "ImageGroup.          (line   6")
    ("imageLattice" . "imageLattice.        (line   6")
    ("ImageVariety" . "ImageVariety.        (line   6")
    ("imap" . "imap.                (line   6")
    ("imap (plural)" . "imap (plural).       (line   6")
    ("Imap, option" . "option.              (line 165")
    ("imapall" . "imapall.             (line   6")
    ("impart" . "impart.              (line   6")
    ("Implemented algorithms" . "Implemented algorithms")
    ("importfrom" . "importfrom.          (line   6")
    ("iMult" . "iMult.               (line   6")
    ("IN" . "lead.                (line  18")
    ("inCenter" . "inCenter.            (line   6")
    ("inCentralizer" . "inCentralizer.       (line   6")
    ("Incl" . "Incl.                (line   6")
    ("indepSet" . "indepSet.            (line   6")
    ("Index" . "Index.               (line   6")
    ("indexed names" . "Names.               (line   6")
    ("indSet" . "indSet.              (line   6")
    ("inequalities" . "inequalities.        (line   6")
    ("info" . "The online help system")
    ("Info string" . "Info string.         (line   6")
    ("inForm" . "inForm.              (line   6")
    ("infRedTail, option" . "option.              (line  62")
    ("iniD" . "iniD.                (line   6")
    ("init_debug" . "init_debug.          (line   6")
    ("initial form" . "bfun_lib.            (line  68")
    ("initial ideal" . "bfun_lib.            (line  68")
    ("initial ideal approach" . "dmodvar_lib.         (line  59")
    ("initialForm" . "initialForm.         (line   6")
    ("initialIdeal" . "initialIdeal.        (line   6")
    ("initialIdealW" . "initialIdealW.       (line   6")
    ("initialMalgrange" . "initialMalgrange.    (line   6")
    ("inout.lib" . "inout_lib.           (line   6")
    ("inout_lib" . "inout_lib.           (line   6")
    ("input" . "Input and output.    (line   6")
    ("insert" . "insert.              (line   6")
    ("insertCone" . "insertCone.          (line   6")
    ("insertGenerator" . "insertGenerator.     (line   6")
    ("instructions, downloading" . "Download instructions")
    ("instructions, Macintosh installation" . "Macintosh installation instructions")
    ("instructions, Unix installation" . "Unix installation instructions")
    ("instructions, Windows installation" . "Windows installation instructions")
    ("inSubring" . "inSubring.           (line   6")
    ("int" . "int.                 (line   6")
    ("int declarations" . "int declarations.    (line   6")
    ("int expressions" . "int expressions.     (line   6")
    ("int operations" . "int operations.      (line   6")
    ("int related functions" . "int related functions")
    ("intclMonIdeal" . "intclMonIdeal.       (line   6")
    ("intclToricRing" . "intclToricRing.      (line   6")
    ("integer division" . "Miscellaneous oddities")
    ("integer programming" . "Integer programming. (line   6")
    ("integral basis" . "adjointIdeal.        (line  50")
    ("integral closure" . "normaliz_lib.        (line  50")
    ("integralBasis" . "integralBasis.       (line   6")
    ("integralbasis.lib" . "integralbasis_lib.   (line   6")
    ("integralbasis_lib" . "integralbasis_lib.   (line   6")
    ("integralIdeal" . "integralIdeal.       (line   6")
    ("integralModule" . "integralModule.      (line   6")
    ("integralSection" . "integralSection.     (line   6")
    ("integration of D-module" . "dmodapp_lib.         (line 104")
    ("Interactive use" . "Interactive use.     (line   6")
    ("InterDiv" . "InterDiv.            (line   6")
    ("interface, Emacs" . "Emacs user interface")
    ("interiorLatticePoints" . "interiorLatticePoints")
    ("internalfunctions" . "internalfunctions.   (line   6")
    ("interpolate" . "interpolate.         (line   6")
    ("interpolation" . "interpolation.       (line   6")
    ("interred" . "interred.            (line   6")
    ("Interrupting SINGULAR" . "Interrupting SINGULAR")
    ("intersect" . "intersect.           (line   6")
    ("intersect (plural)" . "intersect (plural).  (line   6")
    ("intersectElim, option" . "option.              (line 142")
    ("intersection" . "intersection.        (line   6")
    ("intersection multiplicity" . "intersection.        (line  21")
    ("intersectionDiv" . "intersectionDiv.     (line   6")
    ("IntersectionMatrix" . "IntersectionMatrix.  (line   6")
    ("intersectionValRingIdeals" . "intersectionValRingIdeals")
    ("intersectionValRings" . "intersectionValRings")
    ("intersectLattices" . "intersectLattices.   (line   6")
    ("intersectMon" . "intersectMon.        (line   6")
    ("intersectSyz, option" . "option.              (line 147")
    ("IntersectWithSub" . "IntersectWithSub.    (line   6")
    ("intersectZ" . "intersectZ.          (line   6")
    ("intInverse" . "intInverse.          (line   6")
    ("intmat" . "intmat.              (line   6")
    ("intmat declarations" . "intmat declarations. (line   6")
    ("intmat expressions" . "intmat expressions.  (line   6")
    ("intmat operations" . "intmat operations.   (line   6")
    ("intmat related functions" . "intmat related functions")
    ("intmat type cast" . "intmat type cast.    (line   6")
    ("intmat2mons" . "intmat2mons.         (line   6")
    ("intmatToPolymake" . "intmatToPolymake.    (line   6")
    ("intPart" . "intPart.             (line   6")
    ("intprog.lib" . "intprog_lib.         (line   6")
    ("intprog_lib" . "intprog_lib.         (line   6")
    ("intRank" . "intRank.             (line   6")
    ("Introduction" . "Introduction.        (line   6")
    ("intRoot" . "intRoot.             (line   6")
    ("intRoots" . "intRoots.            (line   6")
    ("intStrategy, option" . "option.              (line  69")
    ("intvec" . "intvec.              (line   6")
    ("intvec declarations" . "intvec declarations. (line   6")
    ("intvec expressions" . "intvec expressions.  (line   6")
    ("intvec operations" . "intvec operations.   (line   6")
    ("intvec related functions" . "intvec related functions")
    ("invariant ring minimal generating set matrix group" . "invariant_algebra_reynolds")
    ("invariant ring minimal generating set permutation group" . "invariant_algebra_perm")
    ("Invariant theory" . "Invariant theory.    (line   6")
    ("Invariant Theory" . "Invariant Theory.    (line   6")
    ("invariant_algebra_perm" . "invariant_algebra_perm")
    ("invariant_algebra_reynolds" . "invariant_algebra_reynolds")
    ("invariant_basis" . "invariant_basis.     (line   6")
    ("invariant_basis_reynolds" . "invariant_basis_reynolds")
    ("invariant_ring" . "invariant_ring.      (line   6")
    ("invariant_ring_random" . "invariant_ring_random")
    ("InvariantQ" . "InvariantQ.          (line   6")
    ("InvariantRing" . "InvariantRing.       (line   6")
    ("invariantRing" . "invariantRing.       (line   6")
    ("invariants" . "invariants.          (line   6")
    ("Invariants of a finite group" . "Invariants of a finite group")
    ("Invariants of plane curve singularities" . "Invariants of plane curve singularities")
    ("inverse" . "inverse.             (line   6")
    ("inverse of a matrix via its LU-decomposition" . "luinverse.    (line   6")
    ("inverse_B" . "inverse_B.           (line   6")
    ("inverse_L" . "inverse_L.           (line   6")
    ("inverseFourier" . "inverseFourier.      (line   6")
    ("invertBirMap" . "invertBirMap.        (line   6")
    ("invertNumberMain" . "invertNumberMain.    (line   6")
    ("involut.lib" . "involut_lib.         (line   6")
    ("involut_lib" . "involut_lib.         (line   6")
    ("involution" . "involution.          (line   6")
    ("invunit" . "invunit.             (line   6")
    ("iostruct" . "iostruct.            (line   6")
    ("irred_secondary_char0" . "irred_secondary_char0")
    ("irred_secondary_no_molien" . "irred_secondary_no_molien")
    ("irreddecMon" . "irreddecMon.         (line   6")
    ("irreducible power series" . "is_irred.            (line  26")
    ("irreducible secondary invariant" . "irred_secondary_char0")
    ("irrRealizationDim" . "irrRealizationDim.   (line   6")
    ("is_active" . "is_active.           (line   6")
    ("is_bijective" . "is_bijective.        (line   6")
    ("is_cenBimodule" . "is_cenBimodule.      (line   6")
    ("is_cenSubbimodule" . "is_cenSubbimodule.   (line   6")
    ("is_ci" . "is_ci.               (line   6")
    ("is_complex" . "is_complex.          (line   6")
    ("is_injective" . "is_injective.        (line   6")
    ("is_irred" . "is_irred.            (line   6")
    ("is_is" . "is_is.               (line   6")
    ("is_nested" . "is_nested.           (line   6")
    ("is_NND" . "is_NND.              (line   6")
    ("is_NP" . "is_NP.               (line   6")
    ("is_pure" . "is_pure.             (line   6")
    ("is_reg" . "is_reg.              (line   6")
    ("is_regs" . "is_regs.             (line   6")
    ("is_surjective" . "is_surjective.       (line   6")
    ("is_zero" . "is_zero.             (line   6")
    ("isAface" . "isAface.             (line   6")
    ("isAntiEndo" . "isAntiEndo.          (line   6")
    ("isartinianMon" . "isartinianMon.       (line   6")
    ("isBounded" . "isBounded.           (line   6")
    ("isCanonical" . "isCanonical.         (line   6")
    ("isCartan" . "isCartan.            (line   6")
    ("isCentral" . "isCentral.           (line   6")
    ("isCI" . "isCI.                (line   6")
    ("isCM" . "isCM.                (line   6")
    ("isCMcod2" . "isCMcod2.            (line   6")
    ("isCommutative" . "isCommutative.       (line   6")
    ("isCompatible" . "isCompatible.        (line   6")
    ("isCompressed" . "isCompressed.        (line   6")
    ("isEqualDivisor" . "isEqualDivisor.      (line   6")
    ("isEquising" . "isEquising.          (line   6")
    ("isFlat" . "isFlat.              (line   6")
    ("isFsat" . "isFsat.              (line   6")
    ("isFullSpace" . "isFullSpace.         (line   6")
    ("isgenericMon" . "isgenericMon.        (line   6")
    ("isGorenstein" . "isGorenstein.        (line   6")
    ("isGradedRingHomomorphism" . "isGradedRingHomomorphism")
    ("isGroup" . "isGroup.             (line   6")
    ("isGroupHomomorphism" . "isGroupHomomorphism. (line   6")
    ("isHolonomic" . "isHolonomic.         (line   6")
    ("isHomogeneous" . "isHomogeneous.       (line   6")
    ("ishyper" . "ishyper.             (line   6")
    ("isInt" . "isInt.               (line   6")
    ("isIntegralSurjective" . "isIntegralSurjective")
    ("isInvolution" . "isInvolution.        (line   6")
    ("isirreducibleMon" . "isirreducibleMon.    (line   6")
    ("isLatticeEmpty" . "isLatticeEmpty.      (line   6")
    ("isLocallyFree" . "isLocallyFree.       (line   6")
    ("isMonomial" . "isMonomial.          (line   6")
    ("isNC" . "isNC.                (line   6")
    ("isNormal" . "isNormal.            (line   6")
    ("isoncurve" . "isoncurve.           (line   6")
    ("isOnCurve" . "isOnCurve.           (line   6")
    ("isOrigin" . "isOrigin.            (line   6")
    ("isparam" . "isparam.             (line   6")
    ("isPositive" . "isPositive.          (line   6")
    ("isprimaryMon" . "isprimaryMon.        (line   6")
    ("isprimeMon" . "isprimeMon.          (line   6")
    ("isPrimitiveSublattice" . "isPrimitiveSublattice")
    ("isPure" . "isPure.              (line   6")
    ("isRational" . "isRational.          (line   6")
    ("isReflexive" . "isReflexive.         (line   6")
    ("isReg" . "isReg.               (line   6")
    ("IsSCA" . "IsSCA.               (line   6")
    ("isSimplicial" . "isSimplicial.        (line   6")
    ("isSmooth" . "isSmooth.            (line   6")
    ("isSublattice" . "isSublattice.        (line   6")
    ("isSymmetric" . "isSymmetric.         (line   6")
    ("isTame" . "isTame.              (line   6")
    ("isTerminal" . "isTerminal.          (line   6")
    ("isTorsionFree" . "isTorsionFree.       (line   6")
    ("isuni" . "isuni.               (line   6")
    ("isUpperTriangular" . "isUpperTriangular.   (line   6")
    ("isVar" . "isVar.               (line   6")
    ("isVeryAmple" . "isVeryAmple.         (line   6")
    ("isWeyl" . "isWeyl.              (line   6")
    ("isZeroElement" . "isZeroElement.       (line   6")
    ("iv2lp" . "iv2lp.               (line   6")
    ("iv2lpList" . "iv2lpList.           (line   6")
    ("iv2lpMat" . "iv2lpMat.            (line   6")
    ("ivDHilbert" . "ivDHilbert.          (line   6")
    ("ivDHilbertSickle" . "ivDHilbertSickle.    (line   6")
    ("ivDimCheck" . "ivDimCheck.          (line   6")
    ("ivHilbert" . "ivHilbert.           (line   6")
    ("ivKDim" . "ivKDim.              (line   6")
    ("ivL2lpI" . "ivL2lpI.             (line   6")
    ("ivMis2Base" . "ivMis2Base.          (line   6")
    ("ivMis2Dim" . "ivMis2Dim.           (line   6")
    ("ivOrdMisLex" . "ivOrdMisLex.         (line   6")
    ("ivSickle" . "ivSickle.            (line   6")
    ("ivSickleDim" . "ivSickleDim.         (line   6")
    ("ivSickleHil" . "ivSickleHil.         (line   6")
    ("J-marked schemes" . "JMBTest_lib.         (line  15")
    ("J-marked schemes, Borel ideals" . "JMSConst_lib.        (line  15")
    ("jacob" . "jacob.               (line   6")
    ("Jacobi" . "Jacobi.              (line   6")
    ("jacoblift" . "jacoblift.           (line   6")
    ("jacobson" . "jacobson.            (line   6")
    ("Jacobson form" . "jacobson_lib.        (line  58")
    ("Jacobson normal form" . "jacobson_lib.        (line  58")
    ("jacobson.lib" . "jacobson_lib.        (line   6")
    ("jacobson_lib" . "jacobson_lib.        (line   6")
    ("janet" . "janet.               (line   6")
    ("jet" . "jet.                 (line   6")
    ("jInvariant" . "jInvariant.          (line   6")
    ("JMarkedScheme" . "JMarkedScheme.       (line   6")
    ("JMBTest.lib" . "JMBTest_lib.         (line   6")
    ("JMBTest_lib" . "JMBTest_lib.         (line   6")
    ("JMSConst.lib" . "JMSConst_lib.        (line   6")
    ("JMSConst_lib" . "JMSConst_lib.        (line   6")
    ("jOft" . "jOft.                (line   6")
    ("jordan" . "jordan.              (line   6")
    ("jordanbasis" . "jordanbasis.         (line   6")
    ("jordanmatrix" . "jordanmatrix.        (line   6")
    ("jordannf" . "jordannf.            (line   6")
    ("jungfib" . "jungfib.             (line   6")
    ("jungnormal" . "jungnormal.          (line   6")
    ("jungresolve" . "jungresolve.         (line   6")
    ("JuReTopDim" . "JuReTopDim.          (line   6")
    ("JuReZeroDim" . "JuReZeroDim.         (line   6")
    ("katsura" . "katsura.             (line   6")
    ("kbase" . "kbase.               (line   6")
    ("kbase (plural)" . "kbase (plural).      (line   6")
    ("keepring" . "keepring.            (line   6")
    ("kernel" . "kernel.              (line   6")
    ("Kernel of module homomorphisms" . "Kernel of module homomorphisms")
    ("kernelLattice" . "kernelLattice.       (line   6")
    ("kill" . "kill.                (line   6")
    ("killall" . "killall.             (line   6")
    ("killattrib" . "killattrib.          (line   6")
    ("kmemory" . "kmemory.             (line   6")
    ("kohom" . "kohom.               (line   6")
    ("kontrahom" . "kontrahom.           (line   6")
    ("koszul" . "koszul.              (line   6")
    ("KoszulHomology" . "KoszulHomology.      (line   6")
    ("KScoef" . "KScoef.              (line   6")
    ("KSconvert" . "KSconvert.           (line   6")
    ("KSker" . "KSker.               (line   6")
    ("kskernel.lib" . "kskernel_lib.        (line   6")
    ("kskernel_lib" . "kskernel_lib.        (line   6")
    ("KSlinear" . "KSlinear.            (line   6")
    ("KSpencerKernel" . "KSpencerKernel.      (line   6")
    ("laguerre" . "laguerre.            (line   6")
    ("laguerre_solve" . "laguerre_solve.      (line   6")
    ("lastvarGeneral" . "lastvarGeneral.      (line   6")
    ("latex.lib" . "latex_lib.           (line   6")
    ("latex_lib" . "latex_lib.           (line   6")
    ("latticeArea" . "latticeArea.         (line   6")
    ("latticeBasis" . "latticeBasis.        (line   6")
    ("latticeCodegree" . "latticeCodegree.     (line   6")
    ("latticeDegree" . "latticeDegree.       (line   6")
    ("latticePoints" . "latticePoints.       (line   6")
    ("latticeVolume" . "latticeVolume.       (line   6")
    ("laxfrT" . "laxfrT.              (line   6")
    ("laxfrX" . "laxfrX.              (line   6")
    ("lazy, option" . "option.              (line  75")
    ("lcm" . "lcm.                 (line   6")
    ("lcmMon" . "lcmMon.              (line   6")
    ("lcmN" . "lcmN.                (line   6")
    ("lcmofall" . "lcmofall.            (line   6")
    ("lead" . "lead.                (line   6")
    ("leadcoef" . "leadcoef.            (line   6")
    ("leadexp" . "leadexp.             (line   6")
    ("leadmonom" . "leadmonom.           (line   6")
    ("leadmonomial" . "leadmonomial.        (line   6")
    ("Left and two-sided Groebner bases" . "Left and two-sided Groebner bases")
    ("left annihilator ideal" . "dmod_lib.            (line 109")
    ("Left ideal membership" . "Groebner bases in G-algebras")
    ("Left normal form" . "Groebner bases in G-algebras")
    ("leftInverse" . "leftInverse.         (line   6")
    ("leftKernel" . "leftKernel.          (line   6")
    ("length, option" . "option.              (line  80")
    ("LengthSym" . "LengthSym.           (line   6")
    ("LengthSymElement" . "LengthSymElement.    (line   6")
    ("letplaceGBasis" . "letplaceGBasis.      (line   6")
    ("Letterplace" . "LETTERPLACE.         (line   6")
    ("LETTERPLACE" . "LETTERPLACE.         (line   6")
    ("letterplace correspondence" . "Letterplace correspondence")
    ("lex_solve" . "lex_solve.           (line   6")
    ("Lexicographic Groebner bases, computation of" . "Groebner basis conversion")
    ("lexicographical ordering" . "Global orderings.    (line   9")
    ("LIB" . "LIB.                 (line   6")
    ("LIB commands" . "LIB commands.        (line   6")
    ("lib2doc" . "Documentation Tool.  (line   6")
    ("libcdd" . "Preface.             (line   6")
    ("libfac" . "Preface.             (line   6")
    ("libparse" . "libparse.            (line   6")
    ("Libraries" . "Writing procedures and libraries")
    ("Libraries in the SINGULAR Documentation" . "Libraries in the SINGULAR Documentation")
    ("library" . "gitfan_lib.          (line  24")
    ("library, info string" . "template_lib.        (line 137")
    ("library, polybori.lib" . "polybori_lib.        (line  94")
    ("library, template" . "template_lib.        (line   6")
    ("library, template.lib" . "template_lib.        (line 137")
    ("LIBs" . "SINGULAR libraries.  (line   6")
    ("Lie algebra" . "tangentGens.         (line  34")
    ("Lie group" . "maxZeros.            (line  33")
    ("lieBracket" . "lieBracket.          (line   6")
    ("lift" . "lift.                (line   6")
    ("lift (plural)" . "lift (plural).       (line   6")
    ("lift_kbase" . "lift_kbase.          (line   6")
    ("lift_rel_kb" . "lift_rel_kb.         (line   6")
    ("liftstd" . "liftstd.             (line   6")
    ("liftstd (plural)" . "liftstd (plural).    (line   6")
    ("Limitations" . "Limitations.         (line   6")
    ("linalg.lib" . "linalg_lib.          (line   6")
    ("linalg_lib" . "linalg_lib.          (line   6")
    ("linealityDimension" . "linealityDimension.  (line   6")
    ("linealitySpace" . "linealitySpace.      (line   6")
    ("Linear algebra" . "Linear algebra.      (line   6")
    ("Linear code" . "decodegb_lib.        (line  50")
    ("linear code, dual" . "dual_code.           (line  18")
    ("linear code, systematic" . "sys_code.            (line  27")
    ("linear interreduction" . "bfun_lib.            (line  68")
    ("linear_relations" . "linear_relations.    (line   6")
    ("LinearActionQ" . "LinearActionQ.       (line   6")
    ("LinearCombinationQ" . "LinearCombinationQ.  (line   6")
    ("linearCombinations" . "linearCombinations.  (line   6")
    ("LinearizeAction" . "LinearizeAction.     (line   6")
    ("linearlyEquivalent" . "linearlyEquivalent.  (line   6")
    ("linearMapKernel" . "linearMapKernel.     (line   6")
    ("linearpart" . "linearpart.          (line   6")
    ("link" . "Parallelization with MPtcp links")
    ("link declarations" . "link declarations.   (line   6")
    ("link expressions" . "link expressions.    (line   6")
    ("link related functions" . "link related functions")
    ("Links, user interface" . "parallelWaitAll.     (line  23")
    ("linReduce" . "linReduce.           (line   6")
    ("linReduceIdeal" . "linReduceIdeal.      (line   6")
    ("linSyzSolve" . "linSyzSolve.         (line   6")
    ("list" . "list.                (line   6")
    ("list declarations" . "list declarations.   (line   6")
    ("list expressions" . "list expressions.    (line   6")
    ("list operations" . "list operations.     (line   6")
    ("list related functions" . "list related functions")
    ("listvar" . "listvar.             (line   6")
    ("lll" . "lll.                 (line   6")
    ("LLL" . "LLL.                 (line   6")
    ("lll.lib" . "lll_lib.             (line   6")
    ("lll_lib" . "lll_lib.             (line   6")
    ("load" . "load.                (line   6")
    ("Loading a library" . "Loading a library.   (line   6")
    ("loadLib, option" . "option.              (line 176")
    ("loadProc, option" . "option.              (line 179")
    ("local methods" . "locNormal.           (line  50")
    ("local names" . "Names in procedures. (line   6")
    ("Local orderings" . "Local orderings.     (line   6")
    ("local rings, computing in" . "Rings associated to monomial orderings")
    ("local weighted lexicographical ordering" . "Local orderings.   (line  39")
    ("local weighted reverse lexicographical ordering" . "Local orderings")
    ("localInvar" . "localInvar.          (line   6")
    ("localization" . "Rings associated to monomial orderings")
    ("localization of D-module" . "dmodloc_lib.         (line  93")
    ("localstd" . "localstd.            (line   6")
    ("locAtZero" . "locAtZero.           (line   6")
    ("locNormal" . "locNormal.           (line   6")
    ("locnormal.lib" . "locnormal_lib.       (line   6")
    ("locnormal_lib" . "locnormal_lib.       (line   6")
    ("locstd" . "locstd.              (line   6")
    ("Log for matrices" . "matrixLog.           (line  23")
    ("log2" . "log2.                (line   6")
    ("logarithmic annihilator ideal" . "dmod_lib.            (line 109")
    ("Long coefficients" . "Long coefficients.   (line   6")
    ("LOT algorithm" . "dmod_lib.            (line 109")
    ("lp, global ordering" . "Global orderings.    (line   9")
    ("lp2iv" . "lp2iv.               (line   6")
    ("lp2ivId" . "lp2ivId.             (line   6")
    ("lp2lstr" . "lp2lstr.             (line   6")
    ("lpDHilbert" . "lpDHilbert.          (line   6")
    ("lpDHilbertSickle" . "lpDHilbertSickle.    (line   6")
    ("lpDimCheck" . "lpDimCheck.          (line   6")
    ("lpHilbert" . "lpHilbert.           (line   6")
    ("lpId2ivLi" . "lpId2ivLi.           (line   6")
    ("lpKDim" . "lpKDim.              (line   6")
    ("lpMis2Base" . "lpMis2Base.          (line   6")
    ("lpMis2Dim" . "lpMis2Dim.           (line   6")
    ("lpMult" . "lpMult.              (line   6")
    ("lpNF" . "lpNF.                (line   6")
    ("lpOrdMisLex" . "lpOrdMisLex.         (line   6")
    ("lpPower" . "lpPower.             (line   6")
    ("lprint" . "lprint.              (line   6")
    ("lpSickle" . "lpSickle.            (line   6")
    ("lpSickleDim" . "lpSickleDim.         (line   6")
    ("lpSickleHil" . "lpSickleHil.         (line   6")
    ("lres" . "lres.                (line   6")
    ("ls, local ordering" . "Local orderings.     (line  11")
    ("lst2str" . "lst2str.             (line   6")
    ("LU-decomposition of a matrix of numbers" . "ludecomp.          (line   6")
    ("ludecomp" . "ludecomp.            (line   6")
    ("luinverse" . "luinverse.           (line   6")
    ("lusolve" . "lusolve.             (line   6")
    ("M, ordering" . "Matrix orderings.    (line   6")
    ("Macintosh installation" . "Macintosh installation instructions")
    ("magnitude" . "magnitude.           (line   6")
    ("makeDivisor" . "makeDivisor.         (line   6")
    ("makeFormalDivisor" . "makeFormalDivisor.   (line   6")
    ("makeHeisenberg" . "makeHeisenberg.      (line   6")
    ("makeLetterplaceRing" . "makeLetterplaceRing. (line   6")
    ("makeMalgrange" . "makeMalgrange.       (line   6")
    ("makeModElimRing" . "makeModElimRing.     (line   6")
    ("makePDivisor" . "makePDivisor.        (line   6")
    ("makeQsl2" . "makeQsl2.            (line   6")
    ("makeQsl3" . "makeQsl3.            (line   6")
    ("makeQso3" . "makeQso3.            (line   6")
    ("makeUe6" . "makeUe6.             (line   6")
    ("makeUe7" . "makeUe7.             (line   6")
    ("makeUe8" . "makeUe8.             (line   6")
    ("makeUf4" . "makeUf4.             (line   6")
    ("makeUg2" . "makeUg2.             (line   6")
    ("makeUgl" . "makeUgl.             (line   6")
    ("makeUsl" . "makeUsl.             (line   6")
    ("makeUsl2" . "makeUsl2.            (line   6")
    ("makeUso10" . "makeUso10.           (line   6")
    ("makeUso11" . "makeUso11.           (line   6")
    ("makeUso12" . "makeUso12.           (line   6")
    ("makeUso5" . "makeUso5.            (line   6")
    ("makeUso6" . "makeUso6.            (line   6")
    ("makeUso7" . "makeUso7.            (line   6")
    ("makeUso8" . "makeUso8.            (line   6")
    ("makeUso9" . "makeUso9.            (line   6")
    ("makeUsp1" . "makeUsp1.            (line   6")
    ("makeUsp2" . "makeUsp2.            (line   6")
    ("makeUsp3" . "makeUsp3.            (line   6")
    ("makeUsp4" . "makeUsp4.            (line   6")
    ("makeUsp5" . "makeUsp5.            (line   6")
    ("makeWeyl" . "makeWeyl.            (line   6")
    ("map" . "map.                 (line   6")
    ("map (plural)" . "map (plural).        (line   6")
    ("map declarations" . "map declarations.    (line   6")
    ("map declarations (plural)" . "map declarations (plural)")
    ("map expressions" . "map expressions.     (line   6")
    ("map expressions (plural)" . "map expressions (plural)")
    ("map operations" . "map operations.      (line   6")
    ("map operations (plural)" . "map operations (plural)")
    ("map related functions" . "map related functions")
    ("map related functions  (plural)" . "map related functions (plural)")
    ("mapall" . "mapall.              (line   6")
    ("mapIsFinite" . "mapIsFinite.         (line   6")
    ("mapToRatNormCurve" . "mapToRatNormCurve.   (line   6")
    ("markov4ti2" . "markov4ti2.          (line   6")
    ("mat_rk" . "mat_rk.              (line   6")
    ("matbil" . "matbil.              (line   6")
    ("Mathematical background" . "Mathematical background")
    ("Mathematical background (plural)" . "Mathematical background (plural)")
    ("mathematical objects" . "Representation of mathematical objects")
    ("mathinit" . "mathinit.            (line   6")
    ("matmult" . "matmult.             (line   6")
    ("matrix" . "matrix.              (line   6")
    ("matrix declarations" . "matrix declarations. (line   6")
    ("matrix diagonalization" . "jacobson_lib.        (line  58")
    ("matrix expressions" . "matrix expressions.  (line   6")
    ("matrix operations" . "matrix operations.   (line   6")
    ("Matrix orderings" . "Matrix orderings.    (line   6")
    ("matrix related functions" . "matrix related functions")
    ("matrix type cast" . "matrix type cast.    (line   6")
    ("matrix.lib" . "matrix_lib.          (line   6")
    ("matrix_lib" . "matrix_lib.          (line   6")
    ("matrixExp" . "matrixExp.           (line   6")
    ("matrixLog" . "matrixLog.           (line   6")
    ("matrixsystem" . "matrixsystem.        (line   6")
    ("matrixT1" . "matrixT1.            (line   6")
    ("Max" . "Max.                 (line   6")
    ("maxabs" . "maxabs.              (line   6")
    ("maxcoef" . "maxcoef.             (line   6")
    ("maxdeg" . "maxdeg.              (line   6")
    ("maxdeg1" . "maxdeg1.             (line   6")
    ("maxEord" . "maxEord.             (line   6")
    ("maxideal" . "maxideal.            (line   6")
    ("maximalFace" . "maximalFace.         (line   6")
    ("maximalValue" . "maximalValue.        (line   6")
    ("maximum" . "maximum.             (line   6")
    ("maximum number of zeroes" . "maxZeros.            (line  33")
    ("Maximus" . "Maximus.             (line   6")
    ("maxIntRoot" . "maxIntRoot.          (line   6")
    ("Maxord" . "Maxord.              (line   6")
    ("maxZeros" . "maxZeros.            (line   6")
    ("mdouble" . "mdouble.             (line   6")
    ("mem, option" . "option.              (line 182")
    ("membershipMon" . "membershipMon.       (line   6")
    ("memory" . "memory.              (line   6")
    ("memory managment" . "memory.              (line   6")
    ("midpoint" . "midpoint.            (line   6")
    ("MillerRabin" . "MillerRabin.         (line   6")
    ("milnor" . "milnor.              (line   6")
    ("Milnor number" . "milnornumber.        (line  14")
    ("milnorcode" . "milnorcode.          (line   6")
    ("milnornumber" . "milnornumber.        (line   6")
    ("Min" . "Min.                 (line   6")
    ("minAssChar" . "minAssChar.          (line   6")
    ("minAssGTZ" . "minAssGTZ.           (line   6")
    ("minAssZ" . "minAssZ.             (line   6")
    ("minbase" . "minbase.             (line   6")
    ("minbaseMon" . "minbaseMon.          (line   6")
    ("mindeg" . "mindeg.              (line   6")
    ("mindeg1" . "mindeg1.             (line   6")
    ("mindist" . "mindist.             (line   6")
    ("minEcart" . "minEcart.            (line   6")
    ("minimal display time, setting the" . "system.              (line  88")
    ("MinimalDecomposition" . "MinimalDecomposition")
    ("minimalFace" . "minimalFace.         (line   6")
    ("minimalValue" . "minimalValue.        (line   6")
    ("Minimum distance" . "decodegb_lib.        (line  50")
    ("Minimus" . "Minimus.             (line   6")
    ("minIntRoot" . "minIntRoot.          (line   6")
    ("minIntRoot2" . "minIntRoot2.         (line   6")
    ("minipoly" . "minipoly.            (line   6")
    ("minkowskiSum" . "minkowskiSum.        (line   6")
    ("minMult" . "minMult.             (line   6")
    ("minor" . "minor.               (line   6")
    ("minpoly" . "minpoly.             (line   6")
    ("minres" . "minres.              (line   6")
    ("minres (plural)" . "minres (plural).     (line   6")
    ("Miscellaneous libraries" . "Miscellaneous libraries")
    ("mixed Hodge structure" . "goodBasis.           (line  22")
    ("mod" . "number operations.   (line   6")
    ("mod2id" . "mod2id.              (line   6")
    ("mod2str" . "mod2str.             (line   6")
    ("mod_versal" . "mod_versal.          (line   6")
    ("modality" . "modality.            (line   6")
    ("modDec" . "modDec.              (line   6")
    ("ModEqn" . "ModEqn.              (line   6")
    ("modHenselStd" . "modHenselStd.        (line   6")
    ("modNormal" . "modNormal.           (line   6")
    ("modnormal.lib" . "modnormal_lib.       (line   6")
    ("modnormal_lib" . "modnormal_lib.       (line   6")
    ("modNPos" . "modNPos.             (line   6")
    ("modNpos_test" . "modNpos_test.        (line   6")
    ("modregCM" . "modregCM.            (line   6")
    ("modS" . "modS.                (line   6")
    ("modsatiety" . "modsatiety.          (line   6")
    ("modStd" . "modStd.              (line   6")
    ("modstd.lib" . "modstd_lib.          (line   6")
    ("modstd_lib" . "modstd_lib.          (line   6")
    ("modular methods" . "modnormal_lib.       (line  41")
    ("modular methods." . "locNormal.           (line  50")
    ("modular techniques." . "modNormal.           (line  37")
    ("module" . "module.              (line   6")
    ("module (plural)" . "module (plural).     (line   6")
    ("module declarations" . "module declarations. (line   6")
    ("module declarations (plural)" . "module declarations (plural)")
    ("module expressions" . "module expressions.  (line   6")
    ("module expressions (plural)" . "module expressions (plural)")
    ("module operations" . "module operations.   (line   6")
    ("module operations (plural)" . "module operations (plural)")
    ("module ordering c" . "Module orderings.    (line  49")
    ("module ordering C" . "Module orderings.    (line  19")
    ("Module orderings" . "Module orderings.    (line   6")
    ("module related functions" . "module related functions")
    ("module related functions (plural)" . "module related functions (plural)")
    ("module_containment" . "module_containment.  (line   6")
    ("Modules and and their annihilator" . "Modules and their annihilator")
    ("modulo" . "modulo.              (line   6")
    ("modulo (plural)" . "modulo (plural).     (line   6")
    ("moduloSlim" . "moduloSlim.          (line   6")
    ("molien" . "molien.              (line   6")
    ("mondromy.lib" . "mondromy_lib.        (line   6")
    ("mondromy_lib" . "mondromy_lib.        (line   6")
    ("monitor" . "monitor.             (line   6")
    ("Monodromy" . "mondromy_lib.        (line  34")
    ("monodromy" . "goodBasis.           (line  22")
    ("monodromyB" . "monodromyB.          (line   6")
    ("monomial" . "monomial.            (line   6")
    ("monomial orderings" . "General definitions for orderings")
    ("Monomial orderings" . "Monomial orderings.  (line   6")
    ("monomial orderings" . "Rings associated to monomial orderings")
    ("monomial orderings introduction" . "Introduction to orderings")
    ("Monomial orderings, Term orderings" . "Term orderings.      (line   6")
    ("monomialideal.lib" . "monomialideal_lib.   (line   6")
    ("monomialideal_lib" . "monomialideal_lib.   (line   6")
    ("monomialInIdeal" . "monomialInIdeal.     (line   6")
    ("monomialLcm" . "monomialLcm.         (line   6")
    ("monomials and precedence" . "Miscellaneous oddities")
    ("mons2intmat" . "mons2intmat.         (line   6")
    ("Morse lemma" . "realmorsesplit.      (line  23")
    ("morsesplit" . "morsesplit.          (line   6")
    ("MP" . "Preface.             (line   6")
    ("MP links" . "MP links.            (line   6")
    ("MP, groebner basis computations" . "groebner.            (line  52")
    ("mp_res_mat" . "mp_res_mat.          (line   6")
    ("MPfile links" . "MPfile links.        (line   6")
    ("mplot" . "mplot.               (line   6")
    ("mpresmat" . "mpresmat.            (line   6")
    ("mprimdec.lib" . "mprimdec_lib.        (line   6")
    ("mprimdec_lib" . "mprimdec_lib.        (line   6")
    ("MPtcp" . "Parallelization with MPtcp links")
    ("MPtcp links" . "MPtcp links.         (line   6")
    ("mregular.lib" . "mregular_lib.        (line   6")
    ("mregular_lib" . "mregular_lib.        (line   6")
    ("mres" . "mres.                (line   6")
    ("mres (plural)" . "mres (plural).       (line   6")
    ("mstd" . "mstd.                (line   6")
    ("msum" . "msum.                (line   6")
    ("mtriple" . "mtriple.             (line   6")
    ("mult" . "Miscellaneous oddities")
    ("multBound" . "multBound.           (line   6")
    ("multcol" . "multcol.             (line   6")
    ("multdivisor" . "multdivisor.         (line   6")
    ("multformaldivisor" . "multformaldivisor.   (line   6")
    ("multi" . "multi.               (line   6")
    ("multi indices" . "Names.               (line   6")
    ("multiDeg" . "multiDeg.            (line   6")
    ("multiDegBasis" . "multiDegBasis.       (line   6")
    ("multiDegGroebner" . "multiDegGroebner.    (line   6")
    ("multiDegModulo" . "multiDegModulo.      (line   6")
    ("multiDegPartition" . "multiDegPartition.   (line   6")
    ("multiDegResolution" . "multiDegResolution.  (line   6")
    ("multiDegSyzygy" . "multiDegSyzygy.      (line   6")
    ("multiDegTensor" . "multiDegTensor.      (line   6")
    ("multiDegTor" . "multiDegTor.         (line   6")
    ("multigrading, multidegree, multiweights, multigraded-homogeneous, integral linear algebra" . "multigrading_lib")
    ("multigrading.lib" . "multigrading_lib.    (line   9")
    ("multigrading_lib" . "multigrading_lib.    (line   9")
    ("multiplicities, sequence of" . "invariants.          (line  47")
    ("multiplicity sequence" . "multsequence.        (line  57")
    ("MultiplicitySequence" . "MultiplicitySequence")
    ("multiplylist" . "multiplylist.        (line   6")
    ("multivariate equations" . "ffsolve_lib.         (line  15")
    ("multRat" . "multRat.             (line   6")
    ("multrow" . "multrow.             (line   6")
    ("multseq2charexp" . "multseq2charexp.     (line   6")
    ("multsequence" . "multsequence.        (line   6")
    ("MVComplex" . "MVComplex.           (line   6")
    ("nameof" . "nameof.              (line   6")
    ("names" . "names.               (line   6")
    ("Names" . "Names.               (line   6")
    ("Names in procedures" . "Names in procedures. (line   6")
    ("Names, indexed" . "Names.               (line   6")
    ("nashmult" . "nashmult.            (line   6")
    ("nblocks" . "system.              (line  67")
    ("nBoundaryLatticePoints" . "nBoundaryLatticePoints")
    ("nc_algebra" . "nc_algebra.          (line   6")
    ("ncalg.lib" . "ncalg_lib.           (line   6")
    ("ncalg_lib" . "ncalg_lib.           (line   6")
    ("ncalgebra" . "ncalgebra.           (line   6")
    ("ncdecomp.lib" . "ncdecomp_lib.        (line   6")
    ("ncdecomp_lib" . "ncdecomp_lib.        (line   6")
    ("ncdetection" . "ncdetection.         (line   6")
    ("ncExt_R" . "ncExt_R.             (line   6")
    ("ncfactor.lib" . "ncfactor_lib.        (line   6")
    ("ncfactor_lib" . "ncfactor_lib.        (line   6")
    ("ncHom" . "ncHom.               (line   6")
    ("nchomolog.lib" . "nchomolog_lib.       (line   6")
    ("nchomolog_lib" . "nchomolog_lib.       (line   6")
    ("ncols" . "ncols.               (line   6")
    ("ncones" . "ncones.              (line   6")
    ("ncpreim.lib" . "ncpreim_lib.         (line   6")
    ("ncpreim_lib" . "ncpreim_lib.         (line   6")
    ("ncRelations" . "ncRelations.         (line   6")
    ("nctools.lib" . "nctools_lib.         (line   6")
    ("nctools_lib" . "nctools_lib.         (line   6")
    ("ndcond" . "ndcond.              (line   6")
    ("negatedCone" . "negatedCone.         (line   6")
    ("negative degree lexicographical ordering" . "Local orderings.  (line  25")
    ("negative degree reverse lexicographical ordering" . "Local orderings")
    ("negative lexicographical ordering" . "Local orderings.     (line  11")
    ("negativedivisor" . "negativedivisor.     (line   6")
    ("negativeformaldivisor" . "negativeformaldivisor")
    ("net access" . "Command line options")
    ("newline" . "string.              (line   6")
    ("news" . "News and changes.    (line   6")
    ("newstruct" . "polybori_lib.        (line  94")
    ("newTest" . "newTest.             (line   6")
    ("Newton non-degenerate" . "is_NND.              (line  19")
    ("Newton polygon" . "is_NND.              (line  19")
    ("Newton polytope" . "oldpolymake_lib.     (line  69")
    ("newtonDiag" . "newtonDiag.          (line   6")
    ("newtonpoly" . "newtonpoly.          (line   6")
    ("newtonPolytope" . "newtonPolytope.      (line   6")
    ("newtonPolytopeLP" . "newtonPolytopeLP.    (line   6")
    ("newtonPolytopeP" . "newtonPolytopeP.     (line   6")
    ("NF" . "reduce (plural).     (line   6")
    ("nf_icis" . "nf_icis.             (line   6")
    ("NFMora" . "NFMora.              (line   6")
    ("nHilbertBasis" . "nHilbertBasis.       (line   6")
    ("nilpotent Lie algebras" . "orbitparam_lib.      (line  49")
    ("nInteriorLatticePoints" . "nInteriorLatticePoints")
    ("nLatticePoints" . "nLatticePoints.      (line   6")
    ("nmaxcones" . "nmaxcones.           (line   6")
    ("noether" . "noether.             (line   6")
    ("noether.lib" . "noether_lib.         (line   6")
    ("noether_lib" . "noether_lib.         (line   6")
    ("noetherNormal" . "noetherNormal.       (line   6")
    ("NoetherPosition" . "NoetherPosition.     (line   6")
    ("Non-commutative algebra" . "Non-commutative algebra")
    ("Non-commutative libraries" . "Non-commutative libraries")
    ("Non-commutative LIBs" . "Non-commutative libraries")
    ("Non-commutative subsystem" . "Non-commutative subsystem")
    ("non-english special characters" . "Limitations.         (line  53")
    ("none, option" . "option.              (line  49")
    ("Nonhyp" . "Nonhyp.              (line   6")
    ("nonMonomials" . "nonMonomials.        (line   6")
    ("nonZeroEntry" . "nonZeroEntry.        (line   6")
    ("norm" . "norm.                (line   6")
    ("normal" . "normal.              (line   6")
    ("Normal form" . "Standard bases.      (line  18")
    ("normal.lib" . "normal_lib.          (line   6")
    ("normal_lib" . "normal_lib.          (line   6")
    ("normalC" . "normalC.             (line   6")
    ("normalFan" . "normalFan(polymake). (line   6")
    ("normalForm" . "normalForm.          (line   6")
    ("normalform" . "normalform.          (line   6")
    ("normalI" . "normalI.             (line   6")
    ("normaliz" . "normaliz.            (line   6")
    ("normaliz.lib" . "normaliz_lib.        (line   6")
    ("normaliz_lib" . "normaliz_lib.        (line   6")
    ("normalization" . "modNormal.           (line  37")
    ("Normalization" . "Normalization.       (line   6")
    ("normalization." . "adjointIdeal.        (line  50")
    ("normalize" . "normalize.           (line   6")
    ("normalP" . "normalP.             (line   6")
    ("normalToricRing" . "normalToricRing.     (line   6")
    ("normalToricRingFromBinomials" . "normalToricRingFromBinomials")
    ("norTest" . "norTest.             (line   6")
    ("not" . "boolean operations.  (line   6")
    ("notBuckets, option" . "option.              (line  91")
    ("notRegularity, option" . "option.              (line  83")
    ("notSugar, option" . "option.              (line  87")
    ("notWarnSB, option" . "option.              (line 185")
    ("npar" . "npar.                (line   6")
    ("npars" . "npars.               (line   6")
    ("NPos" . "NPos.                (line   6")
    ("NPos_test" . "NPos_test.           (line   6")
    ("nres" . "nres.                (line   6")
    ("nres (plural)" . "nres (plural).       (line   6")
    ("nrows" . "nrows.               (line   6")
    ("nrroots" . "nrroots.             (line   6")
    ("nrRootsDeterm" . "nrRootsDeterm.       (line   6")
    ("nrRootsProbab" . "nrRootsProbab.       (line   6")
    ("nsatiety" . "nsatiety.            (line   6")
    ("nselect" . "nselect.             (line   6")
    ("NSplaces" . "NSplaces.            (line   6")
    ("nt_solve" . "nt_solve.            (line   6")
    ("NTL" . "Preface.             (line   6")
    ("ntsolve.lib" . "ntsolve_lib.         (line   6")
    ("ntsolve_lib" . "ntsolve_lib.         (line   6")
    ("NullCone" . "NullCone.            (line   6")
    ("number" . "number.              (line   6")
    ("number declarations" . "number declarations. (line   6")
    ("number expressions" . "number expressions.  (line   6")
    ("number operations" . "number operations.   (line   6")
    ("number related functions" . "number related functions")
    ("number_e" . "number_e.            (line   6")
    ("number_pi" . "number_pi.           (line   6")
    ("numberOfConesOfDimension" . "numberOfConesOfDimension")
    ("numerAlg.lib" . "numerAlg_lib.        (line  13")
    ("numerAlg_lib" . "numerAlg_lib.        (line  13")
    ("numerator" . "numerator.           (line   6")
    ("numerDecom.lib" . "numerDecom_lib.      (line  13")
    ("numerDecom_lib" . "numerDecom_lib.      (line  13")
    ("NumIrrDecom" . "NumIrrDecom.         (line   6")
    ("NumLocalDim" . "NumLocalDim.         (line   6")
    ("NumPrimDecom" . "NumPrimDecom.        (line   6")
    ("nvars" . "nvars.               (line   6")
    ("Oaku-Takayama algorithm" . "dmod_lib.            (line 109")
    ("Objects" . "Objects.             (line   6")
    ("oldpolymake.lib" . "oldpolymake_lib.     (line   6")
    ("oldpolymake_lib" . "oldpolymake_lib.     (line   6")
    ("oneDimBelongSemigroup" . "oneDimBelongSemigroup")
    ("online help" . "The online help system")
    ("open" . "open.                (line   6")
    ("opentex" . "opentex.             (line   6")
    ("operatorBM" . "operatorBM.          (line   6")
    ("operatorModulo" . "operatorModulo.      (line   6")
    ("oppose" . "oppose.              (line   6")
    ("opposite" . "opposite.            (line   6")
    ("option" . "option.              (line   6")
    ("or" . "Evaluation of logical expressions")
    ("orbit" . "maxZeros.            (line  33")
    ("orbit_variety" . "orbit_variety.       (line   6")
    ("orbitCones" . "orbitCones.          (line   6")
    ("orbitparam.lib" . "orbitparam_lib.      (line   6")
    ("orbitparam_lib" . "orbitparam_lib.      (line   6")
    ("ord" . "ord.                 (line   6")
    ("ord_test" . "ord_test.            (line   6")
    ("orderings" . "General definitions for orderings")
    ("orderings introduction" . "Introduction to orderings")
    ("orderings, a" . "Extra weight vector. (line   6")
    ("orderings, global" . "Global orderings.    (line   6")
    ("orderings, local" . "Local orderings.     (line   6")
    ("orderings, M" . "Matrix orderings.    (line   6")
    ("orderings, product" . "Product orderings.   (line   6")
    ("ordstr" . "ordstr.              (line   6")
    ("orthogonalize" . "orthogonalize.       (line   6")
    ("outer" . "outer.               (line   6")
    ("output" . "Input and output.    (line   6")
    ("Output, formatting of" . "Formatting output.   (line   6")
    ("p-adic numbers, l-adic numbers, projective limes" . "Coefficient rings")
    ("package" . "package.             (line   6")
    ("package declarations" . "package declarations")
    ("package related functions" . "package related functions")
    ("pairset" . "pairset.             (line   6")
    ("par" . "par.                 (line   6")
    ("par2varRing" . "par2varRing.         (line   6")
    ("paraConic" . "paraConic.           (line   6")
    ("parallel.lib" . "parallel_lib.        (line   6")
    ("parallel_lib" . "parallel_lib.        (line   6")
    ("Parallelization" . "parallelWaitAll.     (line  23")
    ("parallelWaitAll" . "parallelWaitAll.     (line   6")
    ("parallelWaitFirst" . "parallelWaitFirst.   (line   6")
    ("parallelWaitN" . "parallelWaitN.       (line   6")
    ("param" . "param.               (line   6")
    ("Parameter list" . "Parameter list.      (line   6")
    ("parameter, as numbers" . "number.              (line   6")
    ("Parameters" . "Parameters.          (line   6")
    ("parameterSubstitute" . "parameterSubstitute. (line   6")
    ("parametric annihilator" . "dmod_lib.            (line 109")
    ("parametric annihilator for variety" . "dmodvar_lib.         (line  59")
    ("parametrization" . "parametrizeOrbit.    (line  34")
    ("Parametrization" . "paraplanecurves_lib. (line  73")
    ("Parametrization, image." . "testParametrization. (line  26")
    ("parametrizeOrbit" . "parametrizeOrbit.    (line   6")
    ("paraPlaneCurve" . "paraPlaneCurve.      (line   6")
    ("paraplanecurves.lib" . "paraplanecurves_lib. (line   6")
    ("paraplanecurves_lib" . "paraplanecurves_lib. (line   6")
    ("pardeg" . "pardeg.              (line   6")
    ("parstr" . "parstr.              (line   6")
    ("partial_molien" . "partial_molien.      (line   6")
    ("PartitionVar" . "PartitionVar.        (line   6")
    ("ParToVar" . "ParToVar.            (line   6")
    ("pause" . "pause.               (line   6")
    ("PBW" . "central_lib.         (line  19")
    ("PBW basis" . "G-algebras.          (line   9")
    ("PBW_eqDeg" . "PBW_eqDeg.           (line   6")
    ("PBW_maxDeg" . "PBW_maxDeg.          (line   6")
    ("PBW_maxMonom" . "PBW_maxMonom.        (line   6")
    ("pdivi" . "pdivi.               (line   6")
    ("pdivisorplus" . "pdivisorplus.        (line   6")
    ("PerfectPowerTest" . "PerfectPowerTest.    (line   6")
    ("permcol" . "permcol.             (line   6")
    ("permrow" . "permrow.             (line   6")
    ("permute_L" . "permute_L.           (line   6")
    ("perron" . "perron.              (line   6")
    ("perron.lib" . "perron_lib.          (line   6")
    ("perron_lib" . "perron_lib.          (line   6")
    ("Perturbation walk" . "pwalk.               (line  22")
    ("PEsolve" . "PEsolve.             (line   6")
    ("pFactor" . "pFactor.             (line   6")
    ("Pfister, Gerhard" . "Preface.             (line 144")
    ("PH_ais" . "PH_ais.              (line   6")
    ("PH_nais" . "PH_nais.             (line   6")
    ("phindex.lib" . "phindex_lib.         (line   6")
    ("phindex_lib" . "phindex_lib.         (line   6")
    ("picksFormula" . "picksFormula.        (line   6")
    ("pid" . "system.              (line  30")
    ("pIntersect" . "pIntersect.          (line   6")
    ("pIntersectSyz" . "pIntersectSyz.       (line   6")
    ("Pipe links" . "Pipe links.          (line   6")
    ("plainInvariants" . "plainInvariants.     (line   6")
    ("plot" . "plot.                (line   6")
    ("plotRot" . "plotRot.             (line   6")
    ("plotRotated" . "plotRotated.         (line   6")
    ("plotRotatedDirect" . "plotRotatedDirect.   (line   6")
    ("plotRotatedList" . "plotRotatedList.     (line   6")
    ("plotRotatedListFromSpecifyList" . "plotRotatedListFromSpecifyList")
    ("PLURAL" . "PLURAL.              (line   6")
    ("PLURAL LIBs" . "Non-commutative libraries")
    ("pmat" . "pmat.                (line   6")
    ("pnormalf" . "pnormalf.            (line   6")
    ("PocklingtonLehmer" . "PocklingtonLehmer.   (line   6")
    ("pointid.lib" . "pointid_lib.         (line   6")
    ("pointid_lib" . "pointid_lib.         (line   6")
    ("Polar curves" . "Polar curves.        (line   6")
    ("PollardRho" . "PollardRho.          (line   6")
    ("polSol" . "polSol.              (line   6")
    ("polSolFiniteRank" . "polSolFiniteRank.    (line   6")
    ("poly" . "poly.                (line   6")
    ("poly (plural)" . "poly (plural).       (line   6")
    ("poly declarations" . "poly declarations.   (line   6")
    ("poly declarations (plural)" . "poly declarations (plural)")
    ("poly expressions" . "poly expressions.    (line   6")
    ("poly expressions (plural)" . "poly expressions (plural)")
    ("poly operations" . "poly operations.     (line   6")
    ("poly operations (plural)" . "poly operations (plural)")
    ("poly related functions" . "poly related functions")
    ("poly related functions (plural)" . "poly related functions (plural)")
    ("poly.lib" . "poly_lib.            (line   6")
    ("poly2list" . "poly2list.           (line   6")
    ("poly2zdd" . "poly2zdd.            (line   6")
    ("poly_lib" . "poly_lib.            (line   6")
    ("polybori" . "polybori_lib.        (line  94")
    ("Polybori, Boolean Groebner Basis" . "disp_zdd.            (line  20")
    ("PolyBoRi, Boolean Groebner Basis" . "zdd2poly.            (line  14")
    ("PolyBoRi, zero-supressed decision diagram" . "poly2zdd.        (line  14")
    ("polybori.lib" . "polybori_lib.        (line   6")
    ("polybori_lib" . "polybori_lib.        (line   6")
    ("polymake" . "oldpolymake_lib.     (line  69")
    ("polymake_so" . "polymake_so.         (line   6")
    ("polymakeKeepTmpFiles" . "polymakeKeepTmpFiles")
    ("polymakePolytope" . "polymakePolytope.    (line   6")
    ("polymakeToIntmat" . "polymakeToIntmat.    (line   6")
    ("Polynomial data" . "Polynomial data.     (line   6")
    ("polynomial solutions" . "dmodloc_lib.         (line  93")
    ("polytope" . "oldpolymake_lib.     (line  69")
    ("polytope related functions" . "polytope related functions")
    ("polytopeViaInequalities" . "polytopeViaInequalities")
    ("polytopeViaPoints" . "polytopeViaPoints.   (line   6")
    ("polyVars" . "polyVars.            (line   6")
    ("pos_def" . "pos_def.             (line   6")
    ("posweight" . "posweight.           (line   6")
    ("Pottier algorithm" . "Pottier.             (line   6")
    ("power" . "power.               (line   6")
    ("power_products" . "power_products.      (line   6")
    ("powerN" . "powerN.              (line   6")
    ("powerpolyX" . "powerpolyX.          (line   6")
    ("powersums" . "powersums.           (line   6")
    ("powerX" . "powerX.              (line   6")
    ("preComp" . "preComp.             (line   6")
    ("Preface" . "Preface.             (line   6")
    ("preimage" . "ncpreim_lib.         (line  62")
    ("preimage (plural)" . "preimage (plural).   (line   6")
    ("preimage under a map between local rings, map between local rings, map between local and global rings" . "preimageLoc")
    ("preimageLattice" . "preimageLattice.     (line   6")
    ("preimageLoc" . "preimageLoc.         (line   6")
    ("preimageNC" . "preimageNC.          (line   6")
    ("prepareAss" . "prepareAss.          (line   6")
    ("prepEmbDiv" . "prepEmbDiv.          (line   6")
    ("prepMat" . "prepMat.             (line   6")
    ("prepRealclassify" . "prepRealclassify.    (line   6")
    ("prepSV" . "prepSV.              (line   6")
    ("presentTree" . "presentTree.         (line   6")
    ("presolve.lib" . "presolve_lib.        (line   6")
    ("presolve_lib" . "presolve_lib.        (line   6")
    ("Primary decomposition" . "Primary decomposition")
    ("primary_char0" . "primary_char0.       (line   6")
    ("primary_char0_no_molien" . "primary_char0_no_molien")
    ("primary_char0_no_molien_random" . "primary_char0_no_molien_random")
    ("primary_char0_random" . "primary_char0_random")
    ("primary_charp" . "primary_charp.       (line   6")
    ("primary_charp_no_molien" . "primary_charp_no_molien")
    ("primary_charp_no_molien_random" . "primary_charp_no_molien_random")
    ("primary_charp_random" . "primary_charp_random")
    ("primary_charp_without" . "primary_charp_without")
    ("primary_charp_without_random" . "primary_charp_without_random")
    ("primary_invariants" . "primary_invariants.  (line   6")
    ("primary_invariants_random" . "primary_invariants_random")
    ("primdec.lib" . "primdec_lib.         (line   6")
    ("primdec_lib" . "primdec_lib.         (line   6")
    ("PrimdecA" . "PrimdecA.            (line   6")
    ("PrimdecB" . "PrimdecB.            (line   6")
    ("primdecGTZ" . "primdecGTZ.          (line   6")
    ("primdecint.lib" . "primdecint_lib.      (line   6")
    ("primdecint_lib" . "primdecint_lib.      (line   6")
    ("primdecMon" . "primdecMon.          (line   6")
    ("primdecSY" . "primdecSY.           (line   6")
    ("primdecZ" . "primdecZ.            (line   6")
    ("prime" . "prime.               (line   6")
    ("primeClosure" . "primeClosure.        (line   6")
    ("primecoeffs" . "primecoeffs.         (line   6")
    ("primefactors" . "primefactors.        (line   6")
    ("primes" . "primes.              (line   6")
    ("primitiv.lib" . "primitiv_lib.        (line   6")
    ("primitiv_lib" . "primitiv_lib.        (line   6")
    ("primitive" . "primitive.           (line   6")
    ("primitive element" . "primitive.           (line  34")
    ("primitive_extra" . "primitive_extra.     (line   6")
    ("primitiveSpan" . "primitiveSpan.       (line   6")
    ("primL" . "primL.               (line   6")
    ("primList" . "primList.            (line   6")
    ("primparam" . "primparam.           (line   6")
    ("primRoot" . "primRoot.            (line   6")
    ("primTest" . "primTest.            (line   6")
    ("principal intersection" . "bfun_lib.            (line  68")
    ("print" . "print.               (line   6")
    ("printf" . "printf.              (line   6")
    ("printGroup" . "printGroup.          (line   6")
    ("printlevel" . "printlevel.          (line   6")
    ("proc" . "proc.                (line   6")
    ("proc declaration" . "proc declaration.    (line   6")
    ("Procedure definition" . "Procedure definition")
    ("procedure, ASCII help" . "mdouble.             (line  19")
    ("procedure, ASCII/Texinfo help" . "msum.                (line  32")
    ("procedure, texinfo help" . "mtriple.             (line  21")
    ("Procedure-specific commands" . "Procedure-specific commands")
    ("Procedures" . "Procedures.          (line   6")
    ("Procedures and libraries" . "Writing procedures and libraries")
    ("Procedures in a library" . "Procedures in a library")
    ("procedures, help string" . "Help string.         (line   6")
    ("procedures, static" . "Procedure definition")
    ("prodcrit" . "prodcrit.            (line   6")
    ("product" . "product.             (line   6")
    ("Product orderings" . "Product orderings.   (line   6")
    ("productgroup" . "productgroup.        (line   6")
    ("Programming" . "Programming.         (line   6")
    ("progress watch" . "option.              (line  98")
    ("projective dimension" . "purityfiltration_lib")
    ("projectiveDimension" . "projectiveDimension. (line   6")
    ("projectLattice" . "projectLattice.      (line   6")
    ("prompt" . "The SINGULAR prompt. (line   6")
    ("prompt, option" . "option.              (line 189")
    ("prot, option" . "option.              (line  98")
    ("protocol of computations" . "option.              (line  98")
    ("proximitymatrix" . "proximitymatrix.     (line   6")
    ("prune" . "prune.               (line   6")
    ("psigncnd" . "psigncnd.            (line   6")
    ("Puiseux expansion" . "hnoether_lib.        (line  49")
    ("Puiseux pairs" . "invariants.          (line  47")
    ("puiseux2generators" . "puiseux2generators.  (line   6")
    ("puiseuxExpansion" . "puiseuxExpansion.    (line   6")
    ("purelist" . "purelist.            (line   6")
    ("purity" . "purityfiltration_lib")
    ("purityFiltration" . "purityFiltration.    (line   6")
    ("purityfiltration.lib" . "purityfiltration_lib")
    ("purityfiltration_lib" . "purityfiltration_lib")
    ("purityTriang" . "purityTriang.        (line   6")
    ("pushForward" . "pushForward.         (line   6")
    ("pwalk" . "pwalk.               (line   6")
    ("pyobject" . "polybori_lib.        (line  94")
    ("pyobject declarations" . "pyobject declarations")
    ("pyobject expressions" . "pyobject expressions")
    ("pyobject operations" . "pyobject operations. (line   6")
    ("pyobject related functions" . "pyobject related functions")
    ("pyramid" . "pyramid.             (line   6")
    ("python_eval" . "python_eval.         (line   6")
    ("python_import" . "python_import.       (line   6")
    ("python_run" . "python_run.          (line   6")
    ("qbase" . "qbase.               (line   6")
    ("qepcad" . "qepcad.              (line   6")
    ("qepcadsystem" . "qepcadsystem.        (line   6")
    ("qhmatrix" . "qhmatrix.            (line   6")
    ("qhmoduli.lib" . "qhmoduli_lib.        (line   6")
    ("qhmoduli_lib" . "qhmoduli_lib.        (line   6")
    ("qhspectrum" . "qhspectrum.          (line   6")
    ("qhweight" . "qhweight.            (line   6")
    ("qmatrix.lib" . "qmatrix_lib.         (line   6")
    ("qmatrix_lib" . "qmatrix_lib.         (line   6")
    ("qminor" . "qminor.              (line   6")
    ("qrds" . "qrds.                (line   6")
    ("qring" . "Miscellaneous oddities")
    ("qring (plural)" . "qring (plural).      (line   6")
    ("qring declaration" . "qring declaration.   (line   6")
    ("qring declaration (plural)" . "qring declaration (plural)")
    ("qring related functions (plural)" . "qring related functions (plural)")
    ("qringNF, option" . "option.              (line 105")
    ("qslimgb" . "qslimgb.             (line   6")
    ("Qso3Casimir" . "Qso3Casimir.         (line   6")
    ("quadraticSieve" . "quadraticSieve.      (line   6")
    ("quantMat" . "quantMat.            (line   6")
    ("quickclass" . "quickclass.          (line   6")
    ("quit" . "quit.                (line   6")
    ("quote" . "quote.               (line   6")
    ("Quotient" . "Quotient.            (line   6")
    ("quotient" . "quotient.            (line   6")
    ("quotient (plural)" . "quotient (plural).   (line   6")
    ("QuotientEquations" . "QuotientEquations.   (line   6")
    ("quotientLatticeBasis" . "quotientLatticeBasis")
    ("quotientMain" . "quotientMain.        (line   6")
    ("quotientMon" . "quotientMon.         (line   6")
    ("quotients" . "gitfan_lib.          (line  24")
    ("rad_con" . "rad_con.             (line   6")
    ("radical" . "radical.             (line   6")
    ("radicalEHV" . "radicalEHV.          (line   6")
    ("radicalMemberShip" . "radicalMemberShip.   (line   6")
    ("radicalMon" . "radicalMon.          (line   6")
    ("radicalZ" . "radicalZ.            (line   6")
    ("randcharpoly" . "randcharpoly.        (line   6")
    ("randlinpoly" . "randlinpoly.         (line   6")
    ("random" . "random.              (line   6")
    ("random number generator, seed" . "system.              (line  88")
    ("random.lib" . "random_lib.          (line   6")
    ("random_lib" . "random_lib.          (line   6")
    ("randomBinomial" . "randomBinomial.      (line   6")
    ("randomCheck" . "randomCheck.         (line   6")
    ("randomid" . "randomid.            (line   6")
    ("randomLast" . "randomLast.          (line   6")
    ("randommat" . "randommat.           (line   6")
    ("randomPoint" . "randomPoint.         (line   6")
    ("randomPoly" . "randomPoly.          (line   6")
    ("rank" . "rank.                (line   6")
    ("ratgb.lib" . "ratgb_lib.           (line   6")
    ("ratgb_lib" . "ratgb_lib.           (line   6")
    ("Rational curves" . "paraplanecurves_lib. (line  73")
    ("rational curves, rational parametrization of rational curves." . "paraPlaneCurve")
    ("rational normal curve, projection." . "rncItProjEven.      (line  30")
    ("rational solutions" . "dmodloc_lib.         (line  93")
    ("rational univariate projection" . "randcharpoly.        (line  24")
    ("rationalPointConic" . "rationalPointConic.  (line   6")
    ("ratSol" . "ratSol.              (line   6")
    ("ratstd" . "ratstd.              (line   6")
    ("rays" . "rays.                (line   6")
    ("re2squ" . "re2squ.              (line   6")
    ("read" . "read.                (line   6")
    ("reading, option" . "option.              (line 192")
    ("readline" . "Preface.             (line   6")
    ("readNmzData" . "readNmzData.         (line   6")
    ("real" . "Rings and orderings. (line  26")
    ("real roots, univariate polynomial" . "rootsur_lib.         (line  48")
    ("real roots, univariate projection" . "rootsmr_lib.         (line  45")
    ("real roots,sign conditions" . "signcond_lib.        (line  29")
    ("realclassify" . "realclassify.        (line   6")
    ("realclassify.lib" . "realclassify_lib.    (line   6")
    ("realclassify_lib" . "realclassify_lib.    (line   6")
    ("realizationDim" . "realizationDim.      (line   6")
    ("realizationDimPoly" . "realizationDimPoly.  (line   6")
    ("realizationMatroids.lib" . "realizationMatroids_lib")
    ("realizationMatroids_lib" . "realizationMatroids_lib")
    ("realmorsesplit" . "realmorsesplit.      (line   6")
    ("realpoly" . "realpoly.            (line   6")
    ("realrad" . "realrad.             (line   6")
    ("realrad.lib" . "realrad_lib.         (line   6")
    ("realrad_lib" . "realrad_lib.         (line   6")
    ("realzero" . "realzero.            (line   6")
    ("recursive_boolean_poly" . "recursive_boolean_poly")
    ("recursive_from_boolean_poly" . "recursive_from_boolean_poly")
    ("redefine, option" . "option.              (line 195")
    ("redSB, option" . "option.              (line 108")
    ("redTail, option" . "option.              (line 112")
    ("redThrough, option" . "option.              (line 118")
    ("reduce" . "central_lib.         (line  19")
    ("reduce (plural)" . "reduce (plural).     (line   6")
    ("reduced standard basis" . "option.              (line 108")
    ("reduction" . "reduction.           (line   6")
    ("ReesAlgebra" . "ReesAlgebra.         (line   6")
    ("reesclos.lib" . "reesclos_lib.        (line   6")
    ("reesclos_lib" . "reesclos_lib.        (line   6")
    ("reference" . "countedref.          (line   6")
    ("reference declarations" . "reference declarations")
    ("reference expressions" . "reference expressions")
    ("reference operations" . "reference and shared operations")
    ("reference related functions" . "reference and shared related functions")
    ("References" . "References.          (line   6")
    ("References (plural)" . "References (plural). (line   6")
    ("regCM" . "regCM.               (line   6")
    ("regIdeal" . "regIdeal.            (line   6")
    ("regMonCurve" . "regMonCurve.         (line   6")
    ("regularity" . "Syzygies and resolutions")
    ("reiffen" . "reiffen.             (line   6")
    ("ReJunkUseHomo" . "ReJunkUseHomo.       (line   6")
    ("rel_orbit_variety" . "rel_orbit_variety.   (line   6")
    ("relations" . "perron_lib.          (line  21")
    ("relative_orbit_variety" . "relative_orbit_variety")
    ("relativeInteriorPoint" . "relativeInteriorPoint")
    ("Release Notes" . "Release Notes.       (line   6")
    ("relweight" . "relweight.           (line   6")
    ("remainder" . "remainder.           (line   6")
    ("remainderMain" . "remainderMain.       (line   6")
    ("removeCone" . "removeCone.          (line   6")
    ("removepower" . "removepower.         (line   6")
    ("repart" . "repart.              (line   6")
    ("replace" . "replace.             (line   6")
    ("representation, math objects" . "Representation of mathematical objects")
    ("res" . "res.                 (line   6")
    ("resbinomial.lib" . "resbinomial_lib.     (line  15")
    ("resbinomial_lib" . "resbinomial_lib.     (line  15")
    ("reservedName" . "reservedName.        (line   6")
    ("resfunction" . "resfunction.         (line   6")
    ("resgraph.lib" . "resgraph_lib.        (line   6")
    ("resgraph_lib" . "resgraph_lib.        (line   6")
    ("resjung.lib" . "resjung_lib.         (line   6")
    ("resjung_lib" . "resjung_lib.         (line   6")
    ("reslist" . "reslist.             (line   6")
    ("resolution" . "purityfiltration_lib")
    ("Resolution" . "Resolution.          (line   6")
    ("resolution (plural)" . "resolution (plural). (line   6")
    ("resolution declarations" . "resolution declarations")
    ("resolution declarations (plural)" . "resolution declarations (plural)")
    ("resolution expressions" . "resolution expressions")
    ("resolution expressions (plural)" . "resolution expressions (plural)")
    ("resolution graph" . "alexpoly_lib.        (line  40")
    ("Resolution of singularities" . "Resolution of singularities")
    ("resolution related functions" . "resolution related functions")
    ("resolution related functions (plural)" . "resolution related functions (plural)")
    ("resolution, computation of" . "res.                 (line   8")
    ("Resolution, free" . "Free resolution.     (line   6")
    ("resolution, hilbert-driven" . "hres.                (line   6")
    ("resolution, La Scala's method" . "lres.                (line   6")
    ("resolutiongraph" . "resolutiongraph.     (line   6")
    ("resolve" . "resolve.             (line   6")
    ("resolve.lib" . "resolve_lib.         (line   6")
    ("resolve_lib" . "resolve_lib.         (line   6")
    ("ResTree" . "ResTree.             (line   6")
    ("restriction of" . "dmodapp_lib.         (line 104")
    ("restrictionIdeal" . "restrictionIdeal.    (line   6")
    ("restrictionModule" . "restrictionModule.   (line   6")
    ("resultant" . "resultant.           (line   6")
    ("reszeta.lib" . "reszeta_lib.         (line   6")
    ("reszeta_lib" . "reszeta_lib.         (line   6")
    ("return" . "return.              (line   6")
    ("return type of procedures" . "Return type of procedures")
    ("returnSB, option" . "option.              (line  52")
    ("reverse" . "reverse.             (line   6")
    ("reverse lexicographical ordering" . "Global orderings.    (line  14")
    ("reynolds_molien" . "reynolds_molien.     (line   6")
    ("ReynoldsImage" . "ReynoldsImage.       (line   6")
    ("ReynoldsOperator" . "ReynoldsOperator.    (line   6")
    ("rho" . "rho.                 (line   6")
    ("Right Groebner bases and syzygies" . "Right Groebner bases and syzygies")
    ("rightInverse" . "rightInverse.        (line   6")
    ("rightKernel" . "rightKernel.         (line   6")
    ("rightModulo" . "rightModulo.         (line   6")
    ("rightNF" . "rightNF.             (line   6")
    ("rightNFWeyl" . "rightNFWeyl.         (line   6")
    ("rightStd" . "rightStd.            (line   6")
    ("ring" . "ring.                (line   6")
    ("ring (plural)" . "ring (plural).       (line   6")
    ("ring declarations" . "ring declarations.   (line   6")
    ("ring declarations (plural)" . "ring declarations (plural)")
    ("ring operations" . "ring operations.     (line   6")
    ("ring operations (plural)" . "ring operations (plural)")
    ("ring related functions" . "ring related functions")
    ("ring related functions (plural)" . "ring related functions (plural)")
    ("ring, rings" . "setglobalrings.      (line  26")
    ("ring.lib" . "ring_lib.            (line   6")
    ("ring_lib" . "ring_lib.            (line   6")
    ("ringlist" . "ringlist.            (line   6")
    ("ringlist (plural)" . "ringlist (plural).   (line   6")
    ("Rings and orderings" . "Rings and orderings. (line   6")
    ("Rings and standard bases" . "Rings and standard bases")
    ("ringtensor" . "ringtensor.          (line   6")
    ("ringweights" . "ringweights.         (line   6")
    ("rinvar.lib" . "rinvar_lib.          (line   6")
    ("rinvar_lib" . "rinvar_lib.          (line   6")
    ("rm_unitcol" . "rm_unitcol.          (line   6")
    ("rm_unitrow" . "rm_unitrow.          (line   6")
    ("rMacaulay" . "rMacaulay.           (line   6")
    ("rmNmzFiles" . "rmNmzFiles.          (line   6")
    ("rmx" . "rmx.                 (line   6")
    ("rncAntiCanonicalMap" . "rncAntiCanonicalMap. (line   6")
    ("rncItProjEven" . "rncItProjEven.       (line   6")
    ("rncItProjOdd" . "rncItProjOdd.        (line   6")
    ("root of Bernstein-Sato polynomial" . "dmod_lib.            (line 109")
    ("rootofUnity" . "rootofUnity.         (line   6")
    ("roots" . "roots.               (line   6")
    ("rootsMain" . "rootsMain.           (line   6")
    ("rootsModp" . "rootsModp.           (line   6")
    ("rootsmr.lib" . "rootsmr_lib.         (line   6")
    ("rootsmr_lib" . "rootsmr_lib.         (line   6")
    ("rootsur.lib" . "rootsur_lib.         (line   6")
    ("rootsur_lib" . "rootsur_lib.         (line   6")
    ("round" . "round.               (line   6")
    ("rowred" . "rowred.              (line   6")
    ("rp, global ordering" . "Global orderings.    (line  14")
    ("rtimer" . "rtimer.              (line   6")
    ("Running SINGULAR under Emacs" . "Running SINGULAR under Emacs")
    ("rvalue" . "No rvalue of increments and assignments")
    ("rvar" . "rvar.                (line   6")
    ("sa_poly_reduce" . "sa_poly_reduce.      (line   6")
    ("sa_reduce" . "sa_reduce.           (line   6")
    ("safeVarName" . "safeVarName.         (line   6")
    ("sagbi" . "sagbi.               (line   6")
    ("sagbi.lib" . "sagbi_lib.           (line   6")
    ("sagbi_lib" . "sagbi_lib.           (line   6")
    ("sagbiPart" . "sagbiPart.           (line   6")
    ("sagbiReduce" . "sagbiReduce.         (line   6")
    ("sagbiSPoly" . "sagbiSPoly.          (line   6")
    ("salida" . "salida.              (line   6")
    ("sameComponent" . "sameComponent.       (line   6")
    ("sameQ" . "sameQ.               (line   6")
    ("Sannfs" . "Sannfs.              (line   6")
    ("SannfsBFCT" . "SannfsBFCT.          (line   6")
    ("Sannfslog" . "Sannfslog.           (line   6")
    ("SannfsVar" . "SannfsVar.           (line   6")
    ("sat" . "sat.                 (line   6")
    ("satiety" . "satiety.             (line   6")
    ("Saturation" . "Saturation.          (line   6")
    ("SCA" . "Graded commutative algebras (SCA)")
    ("scalarProd" . "scalarProd.          (line   6")
    ("scheme" . "scheme.              (line   6")
    ("Scho\"nemann, Hans" . "Preface.             (line 144")
    ("Schoof" . "Schoof.              (line   6")
    ("SDB breakpoint" . "Source code debugger")
    ("SDB debugger" . "Source code debugger")
    ("sdb, source code debugger" . "Source code debugger")
    ("SDLoc" . "SDLoc.               (line   6")
    ("secondary fan" . "oldpolymake_lib.     (line  69")
    ("secondary polytope" . "oldpolymake_lib.     (line  69")
    ("secondary_and_irreducibles_no_molien" . "secondary_and_irreducibles_no_molien")
    ("secondary_char0" . "secondary_char0.     (line   6")
    ("secondary_charp" . "secondary_charp.     (line   6")
    ("secondary_no_molien" . "secondary_no_molien. (line   6")
    ("secondary_not_cohen_macaulay" . "secondary_not_cohen_macaulay")
    ("secondaryFan" . "secondaryFan.        (line   6")
    ("secondaryPolytope" . "secondaryPolytope.   (line   6")
    ("select" . "select.              (line   6")
    ("select1" . "select1.             (line   6")
    ("semiCMcod2" . "semiCMcod2.          (line   6")
    ("semidiv" . "semidiv.             (line   6")
    ("semigroup" . "charexp2generators.  (line  19")
    ("semigroup of values" . "invariants.          (line  47")
    ("semigroupGenerator" . "semigroupGenerator.  (line   6")
    ("separateHNE" . "separateHNE.         (line   6")
    ("separator" . "separator.           (line   6")
    ("serreRelations" . "serreRelations.      (line   6")
    ("setBaseMultigrading" . "setBaseMultigrading. (line   6")
    ("setenv" . "system.              (line  45")
    ("setglobalrings" . "setglobalrings.      (line   6")
    ("setinitials" . "setinitials.         (line   6")
    ("setLetterplaceAttributes" . "setLetterplaceAttributes")
    ("setLinearForms" . "setLinearForms.      (line   6")
    ("setModuleGrading" . "setModuleGrading.    (line   6")
    ("setMultiplicity" . "setMultiplicity.     (line   6")
    ("setNmzDataPath" . "setNmzDataPath.      (line   6")
    ("setNmzExecPath" . "setNmzExecPath.      (line   6")
    ("setNmzFilename" . "setNmzFilename.      (line   6")
    ("setNmzOption" . "setNmzOption.        (line   6")
    ("setring" . "setring.             (line   6")
    ("Setting up a G-algebra" . "G-algebras.          (line  51")
    ("sh" . "system.              (line  26")
    ("ShanksMestre" . "ShanksMestre.        (line   6")
    ("shared" . "countedref.          (line   6")
    ("shared declarations" . "shared declarations. (line   6")
    ("shared expressions" . "shared expressions.  (line   6")
    ("shared operations" . "reference and shared operations")
    ("shared related functions" . "reference and shared related functions")
    ("sheaf cohomology" . "sheafcoh_lib.        (line  32")
    ("sheafCoh" . "sheafCoh.            (line   6")
    ("sheafcoh.lib" . "sheafcoh_lib.        (line   6")
    ("sheafcoh_lib" . "sheafcoh_lib.        (line   6")
    ("sheafCohBGG" . "sheafCohBGG.         (line   6")
    ("sheafCohBGG2" . "sheafCohBGG2.        (line   6")
    ("shiftPoly" . "shiftPoly.           (line   6")
    ("short" . "short.               (line   6")
    ("show" . "show.                (line   6")
    ("showBO" . "showBO.              (line   6")
    ("showDataTypes" . "showDataTypes.       (line   6")
    ("showgrades" . "showgrades.          (line   6")
    ("showNmzOptions" . "showNmzOptions.      (line   6")
    ("showNuminvs" . "showNuminvs.         (line   6")
    ("showrecursive" . "showrecursive.       (line   6")
    ("sickle" . "sickle.              (line   6")
    ("signatureBrieskorn" . "signatureBrieskorn.  (line   6")
    ("signatureL" . "signatureL.          (line   6")
    ("signatureLqf" . "signatureLqf.        (line   6")
    ("signatureNemethi" . "signatureNemethi.    (line   6")
    ("signaturePuiseux" . "signaturePuiseux.    (line   6")
    ("signcnd" . "signcnd.             (line   6")
    ("signcond.lib" . "signcond_lib.        (line   6")
    ("signcond_lib" . "signcond_lib.        (line   6")
    ("simplesolver" . "simplesolver.        (line   6")
    ("simplex" . "simplex.             (line   6")
    ("simplexOut" . "simplexOut.          (line   6")
    ("simplify" . "simplify.            (line   6")
    ("SimplifyIdeal" . "SimplifyIdeal.       (line   6")
    ("simplifyRat" . "simplifyRat.         (line   6")
    ("sing.lib" . "sing_lib.            (line   6")
    ("sing4ti2.lib" . "sing4ti2_lib.        (line   6")
    ("sing4ti2_lib" . "sing4ti2_lib.        (line   6")
    ("sing_lib" . "sing_lib.            (line   6")
    ("Singular" . "system.              (line  72")
    ("SINGULAR libraries" . "SINGULAR libraries.  (line   6")
    ("singular locus of D-module" . "dmodloc_lib.         (line  93")
    ("Singular, customization of Emacs user interface" . "Customization of the Emacs interface")
    ("Singular, demo mode" . "Demo mode.           (line   6")
    ("Singular, editing input files with Emacs" . "Editing SINGULAR input files with Emacs")
    ("Singular, important commands of Emacs interface" . "Top 20 Emacs commands")
    ("Singular, running within Emacs" . "Running SINGULAR under Emacs")
    ("Singular2bertini" . "Singular2bertini.    (line   6")
    ("SINGULARHIST" . "Editing input.       (line   6")
    ("singularities" . "spectrumnd.          (line  26")
    ("Singularities" . "Singularities.       (line   6")
    ("singularities, resolution of" . "Resolution of singularities")
    ("singularity" . "singularity.         (line   6")
    ("Singularity Theory" . "Singularity Theory.  (line   6")
    ("SingularLib" . "system.              (line  76")
    ("singularrc" . "Startup sequence.    (line  10")
    ("size" . "Miscellaneous oddities")
    ("Skeletons for parallelization" . "parallelWaitAll.     (line  23")
    ("skewmat" . "skewmat.             (line   6")
    ("sleep" . "status.              (line   6")
    ("slimgb" . "slim Groebner bases. (line   6")
    ("slimgb (plural)" . "slimgb (plural).     (line   6")
    ("slocus" . "slocus.              (line   6")
    ("smith" . "smith.               (line   6")
    ("Smith form" . "jacobson_lib.        (line  58")
    ("Smith normal form" . "jacobson_lib.        (line  58")
    ("smithNormalForm" . "smithNormalForm.     (line   6")
    ("SolowayStrassen" . "SolowayStrassen.     (line   6")
    ("solutionsMod2" . "solutionsMod2.       (line   6")
    ("solve" . "solve.               (line   6")
    ("solve a linear equation system A*x = b via the LU-decomposition of A" . "lusolve")
    ("solve.lib" . "solve_lib.           (line   6")
    ("solve_IP" . "solve_IP.            (line   6")
    ("solve_lib" . "solve_lib.           (line   6")
    ("solvelinearpart" . "solvelinearpart.     (line   6")
    ("solveTInitialFormPar" . "solveTInitialFormPar")
    ("Solving systems of polynomial equations" . "Solving systems of polynomial equations")
    ("sort" . "sort.                (line   6")
    ("sortandmap" . "sortandmap.          (line   6")
    ("sortier" . "sortier.             (line   6")
    ("sortIntvec" . "sortIntvec.          (line   6")
    ("sortvars" . "sortvars.            (line   6")
    ("sortvec" . "sortvec.             (line   6")
    ("Source code debugger, invocation" . "Command line options")
    ("source code debugger, sdb" . "Source code debugger")
    ("Space curve singularities, branches of" . "Branches of space curve singularities")
    ("spadd" . "spadd.               (line   6")
    ("span" . "span.                (line   6")
    ("sparseHomogIdeal" . "sparseHomogIdeal.    (line   6")
    ("sparseid" . "sparseid.            (line   6")
    ("sparsemat" . "sparsemat.           (line   6")
    ("sparsematrix" . "sparsematrix.        (line   6")
    ("sparsepoly" . "sparsepoly.          (line   6")
    ("sparsetriag" . "sparsetriag.         (line   6")
    ("spcurve.lib" . "spcurve_lib.         (line   6")
    ("spcurve_lib" . "spcurve_lib.         (line   6")
    ("Special characters" . "Special characters.  (line   6")
    ("special characters, non-english" . "Limitations.         (line  53")
    ("spectral pairs" . "goodBasis.           (line  22")
    ("spectralNeg" . "spectralNeg.         (line   6")
    ("spectrum" . "spectrumnd.          (line  26")
    ("spectrum.lib" . "spectrum_lib.        (line   6")
    ("spectrum_lib" . "spectrum_lib.        (line   6")
    ("spectrumnd" . "spectrumnd.          (line   6")
    ("spgamma" . "spgamma.             (line   6")
    ("spgeomgenus" . "spgeomgenus.         (line   6")
    ("spissemicont" . "spissemicont.        (line   6")
    ("split" . "split.               (line   6")
    ("splitPolygon" . "splitPolygon.        (line   6")
    ("splitring" . "splitring.           (line   6")
    ("splitting" . "splitting.           (line   6")
    ("Splitting lemma" . "realmorsesplit.      (line  23")
    ("spmilnor" . "spmilnor.            (line   6")
    ("spmul" . "spmul.               (line   6")
    ("spnf" . "spnf.                (line   6")
    ("spoly" . "spoly.               (line   6")
    ("sppairs" . "sppairs.             (line   6")
    ("sppnf" . "sppnf.               (line   6")
    ("sppprint" . "sppprint.            (line   6")
    ("spprint" . "spprint.             (line   6")
    ("sprintf" . "sprintf.             (line   6")
    ("spsemicont" . "spsemicont.          (line   6")
    ("spsub" . "spsub.               (line   6")
    ("sqfrNorm" . "sqfrNorm.            (line   6")
    ("sqfrNormMain" . "sqfrNormMain.        (line   6")
    ("sqr" . "sqr.                 (line   6")
    ("sqrfree" . "sqrfree.             (line   6")
    ("squarefree" . "squarefree.          (line   6")
    ("squareRoot" . "squareRoot.          (line   6")
    ("sres" . "sres.                (line   6")
    ("Ssi file links" . "Ssi file links.      (line   6")
    ("Ssi links" . "Ssi links.           (line   6")
    ("Ssi tcp links" . "Ssi tcp links.       (line   6")
    ("StabEqn" . "StabEqn.             (line   6")
    ("StabEqnId" . "StabEqnId.           (line   6")
    ("StabOrder" . "StabOrder.           (line   6")
    ("staircase" . "staircase.           (line   6")
    ("standard" . "standard.            (line   6")
    ("Standard bases" . "Standard bases.      (line   6")
    ("Standard Bases" . "Computing Groebner and Standard Bases")
    ("standard.lib" . "standard_lib.        (line  11")
    ("standard_lib" . "standard_lib.        (line  11")
    ("startNmz" . "startNmz.            (line   6")
    ("StartOrderingV" . "StartOrderingV.      (line   6")
    ("Startup sequence" . "Startup sequence.    (line   6")
    ("static procedures" . "Procedure definition")
    ("status" . "status.              (line   6")
    ("std" . "groebner and std.    (line   6")
    ("std (plural)" . "std (plural).        (line   6")
    ("stdfglm" . "stdfglm.             (line   6")
    ("stdhilb" . "stdhilb.             (line   6")
    ("stratify" . "stratify.            (line   6")
    ("stratify.lib" . "stratify_lib.        (line   6")
    ("stratify_lib" . "stratify_lib.        (line   6")
    ("string" . "Miscellaneous oddities")
    ("string declarations" . "string declarations. (line   6")
    ("string expressions" . "string expressions.  (line   6")
    ("string operations" . "string operations.   (line   6")
    ("string related functions" . "string related functions")
    ("string type cast" . "string type cast.    (line   6")
    ("StringF" . "StringF.             (line   6")
    ("stripHNE" . "stripHNE.            (line   6")
    ("sturm" . "sturm.               (line   6")
    ("sturmha" . "sturmha.             (line   6")
    ("sturmhaseq" . "sturmhaseq.          (line   6")
    ("sturmquery" . "sturmquery.          (line   6")
    ("sturmseq" . "sturmseq.            (line   6")
    ("submat" . "submat.              (line   6")
    ("subrInterred" . "subrInterred.        (line   6")
    ("subst" . "subst.               (line   6")
    ("subst (plural)" . "subst (plural).      (line   6")
    ("substitute" . "substitute.          (line   6")
    ("sugarCrit, option" . "option.              (line 125")
    ("sum" . "sum.                 (line   6")
    ("sumlist" . "sumlist.             (line   6")
    ("super-commutative algebras" . "Graded commutative algebras (SCA)")
    ("superCommutative" . "superCommutative.    (line   6")
    ("surf.lib" . "surf_lib.            (line   6")
    ("surf_lib" . "surf_lib.            (line   6")
    ("surfacesignature.lib" . "surfacesignature_lib")
    ("surfacesignature_lib" . "surfacesignature_lib")
    ("surfer" . "surfer.              (line   6")
    ("surfex" . "Preface.             (line   6")
    ("surfex.lib" . "surfex_lib.          (line   6")
    ("surfex_lib" . "surfex_lib.          (line   6")
    ("SuSE, ESingular bug" . "Unix installation instructions")
    ("suspend" . "status.              (line   6")
    ("SV-decoding algorithm" . "decodeSV.            (line  25")
    ("SV-decoding algorithm, preprocessing" . "prepSV.              (line  51")
    ("swap" . "swap.                (line   6")
    ("switch" . "No case or switch statement")
    ("sym_gauss" . "sym_gauss.           (line   6")
    ("Symbolic-numerical solving" . "Symbolic-numerical solving")
    ("SymGroup" . "SymGroup.            (line   6")
    ("symmat" . "symmat.              (line   6")
    ("symmetric basis" . "symmetricBasis.      (line  18")
    ("symmetric power" . "symmetricPower.      (line  18")
    ("symmetricBasis" . "symmetricBasis.      (line   6")
    ("symmetricPower" . "symmetricPower.      (line   6")
    ("symmfunc" . "symmfunc.            (line   6")
    ("symmStd" . "symmStd.             (line   6")
    ("syModStd" . "syModStd.            (line   6")
    ("symodstd.lib" . "symodstd_lib.        (line   6")
    ("symodstd_lib" . "symodstd_lib.        (line   6")
    ("symsignature" . "symsignature.        (line   6")
    ("syndrome" . "syndrome.            (line   6")
    ("sys_code" . "sys_code.            (line   6")
    ("sysBin" . "sysBin.              (line   6")
    ("sysCRHT" . "sysCRHT.             (line   6")
    ("sysCRHTMindist" . "sysCRHTMindist.      (line   6")
    ("sysFL" . "sysFL.               (line   6")
    ("sysNewton" . "sysNewton.           (line   6")
    ("sysQE" . "sysQE.               (line   6")
    ("system" . "system.              (line   6")
    ("System and Control Theory" . "System and Control Theory")
    ("System dependent limitations" . "System dependent limitations")
    ("System variables" . "System variables.    (line   6")
    ("system, -" . "system.              (line  80")
    ("system, -long_option_name" . "system.              (line  83")
    ("system, -long_option_name=value" . "system.              (line  88")
    ("system, browsers" . "system.              (line  96")
    ("system, contributors" . "system.              (line  56")
    ("system, cpu" . "system.              (line  33")
    ("system, gen" . "system.              (line  60")
    ("system, getenv" . "system.              (line  41")
    ("system, nblocks" . "system.              (line  67")
    ("system, pid" . "system.              (line  30")
    ("system, setenv" . "system.              (line  45")
    ("system, sh" . "system.              (line  26")
    ("system, Singular" . "system.              (line  72")
    ("system, SingularLib" . "system.              (line  76")
    ("system, tty" . "system.              (line  50")
    ("system, uname" . "system.              (line  37")
    ("system, version" . "system.              (line  53")
    ("syz" . "syz.                 (line   6")
    ("syz (plural)" . "syz (plural).        (line   6")
    ("Syzygies and resolutions" . "Syzygies and resolutions")
    ("Syzygies and resolutions (plural)" . "Syzygies and resolutions (plural)")
    ("T1" . "T1 and T2.           (line   6")
    ("T2" . "T1 and T2.           (line   6")
    ("T_1" . "T_1.                 (line   6")
    ("T_12" . "T_12.                (line   6")
    ("T_2" . "T_2.                 (line   6")
    ("tab" . "tab.                 (line   6")
    ("tail" . "tail.                (line   6")
    ("tame polynomial" . "goodBasis.           (line  22")
    ("tangentcone" . "tangentcone.         (line   6")
    ("tangentGens" . "tangentGens.         (line   6")
    ("tau_es" . "tau_es.              (line   6")
    ("tau_es2" . "tau_es2.             (line   6")
    ("tDetropicalise" . "tDetropicalise.      (line   6")
    ("Teaching" . "Teaching.            (line   6")
    ("teachstd.lib" . "teachstd_lib.        (line   6")
    ("teachstd_lib" . "teachstd_lib.        (line   6")
    ("Template for writing a library" . "template_lib.        (line   6")
    ("template.lib" . "template_lib.        (line 128")
    ("template_lib" . "template_lib.        (line   6")
    ("tensor" . "tensor.              (line   6")
    ("tensorMod" . "tensorMod.           (line   6")
    ("term orderings" . "General definitions for orderings")
    ("term orderings introduction" . "Introduction to orderings")
    ("TestJMark" . "TestJMark.           (line   6")
    ("testNCfac" . "testNCfac.           (line   6")
    ("testParametrization" . "testParametrization. (line   6")
    ("testPointConic" . "testPointConic.      (line   6")
    ("testPrimary" . "testPrimary.         (line   6")
    ("tex" . "tex.                 (line   6")
    ("texcoef" . "texcoef.             (line   6")
    ("texdemo" . "texdemo.             (line   6")
    ("texDrawBasic" . "texDrawBasic.        (line   6")
    ("texDrawNewtonSubdivision" . "texDrawNewtonSubdivision")
    ("texDrawTriangulation" . "texDrawTriangulation")
    ("texDrawTropical" . "texDrawTropical.     (line   6")
    ("texfactorize" . "texfactorize.        (line   6")
    ("texmap" . "texmap.              (line   6")
    ("texMatrix" . "texMatrix.           (line   6")
    ("texname" . "texname.             (line   6")
    ("texNumber" . "texNumber.           (line   6")
    ("texobj" . "texobj.              (line   6")
    ("texpoly" . "texpoly.             (line   6")
    ("texPolynomial" . "texPolynomial.       (line   6")
    ("texproc" . "texproc.             (line   6")
    ("texring" . "texring.             (line   6")
    ("the first alternative algorithm" . "awalk1.              (line  24")
    ("The fractal walk algorithm" . "fwalk.               (line  20")
    ("The online help system" . "The online help system")
    ("The SINGULAR language" . "The SINGULAR language")
    ("The Tran algorithm" . "twalk.               (line  20")
    ("time limit on computations" . "groebner.            (line  52")
    ("timeFactorize" . "timeFactorize.       (line   6")
    ("timer" . "timer.               (line   6")
    ("timer resolution, setting the" . "system.              (line  88")
    ("timeStd" . "timeStd.             (line   6")
    ("timestep" . "timestep.            (line   6")
    ("tInitialForm" . "tInitialForm.        (line   6")
    ("tInitialFormPar" . "tInitialFormPar.     (line   6")
    ("tInitialFormParMax" . "tInitialFormParMax.  (line   6")
    ("tInitialIdeal" . "tInitialIdeal.       (line   6")
    ("tjurina" . "tjurina.             (line   6")
    ("Tjurina" . "Tjurina.             (line   6")
    ("Tjurina number" . "deltaLoc.            (line  36")
    ("tmatrix" . "tmatrix.             (line   6")
    ("tolessvars" . "tolessvars.          (line   6")
    ("Top 20 Emacs commands" . "Top 20 Emacs commands")
    ("topological invariants" . "charexp2conductor.   (line  18")
    ("Tor" . "Tor.                 (line   6")
    ("toric ideals" . "Toric ideals.        (line   6")
    ("Toric ideals and integer programming" . "Toric ideals and integer programming")
    ("toric.lib" . "toric_lib.           (line   6")
    ("toric_ideal" . "toric_ideal.         (line   6")
    ("toric_lib" . "toric_lib.           (line   6")
    ("toric_std" . "toric_std.           (line   6")
    ("torusInvariants" . "torusInvariants.     (line   6")
    ("total multiplicities" . "alexpoly_lib.        (line  40")
    ("totalmultiplicities" . "totalmultiplicities. (line   6")
    ("TRACE" . "TRACE var.           (line   6")
    ("trace" . "trace.               (line   6")
    ("tracemult" . "tracemult.           (line   6")
    ("transpose" . "transpose.           (line   6")
    ("trapezoid" . "trapezoid.           (line   6")
    ("triagmatrix" . "triagmatrix.         (line   6")
    ("triang.lib" . "triang_lib.          (line   6")
    ("triang_lib" . "triang_lib.          (line   6")
    ("triang_solve" . "triang_solve.        (line   6")
    ("triangL" . "triangL.             (line   6")
    ("triangL_solve" . "triangL_solve.       (line   6")
    ("triangLf_solve" . "triangLf_solve.      (line   6")
    ("triangLfak" . "triangLfak.          (line   6")
    ("triangM" . "triangM.             (line   6")
    ("triangM_solve" . "triangM_solve.       (line   6")
    ("triangMH" . "triangMH.            (line   6")
    ("triangulations" . "triangulations.      (line   6")
    ("Tricks and pitfalls" . "Tricks and pitfalls. (line   6")
    ("triMNewton" . "triMNewton.          (line   6")
    ("tropical curves" . "tropical_lib.        (line 165")
    ("Tropical Geometry" . "Tropical Geometry.   (line   6")
    ("tropical polynomials" . "tropical_lib.        (line 165")
    ("tropical.lib" . "tropical_lib.        (line   6")
    ("tropical_lib" . "tropical_lib.        (line   6")
    ("tropicalCurve" . "tropicalCurve.       (line   6")
    ("tropicalise" . "tropicalise.         (line   6")
    ("tropicaliseSet" . "tropicaliseSet.      (line   6")
    ("tropicalJInvariant" . "tropicalJInvariant.  (line   6")
    ("tropicalLifting" . "tropicalLifting.     (line   6")
    ("tropicalSubst" . "tropicalSubst.       (line   6")
    ("truncate" . "truncate.            (line   6")
    ("truncated module" . "truncateFast.        (line  28")
    ("truncateFast" . "truncateFast.        (line   6")
    ("tst_ncfactor" . "tst_ncfactor.        (line   6")
    ("tty" . "system.              (line  50")
    ("twalk" . "twalk.               (line   6")
    ("twostd" . "twostd.              (line   6")
    ("type" . "type.                (line   6")
    ("Type casting" . "Type conversion and casting")
    ("Type conversion" . "Type conversion and casting")
    ("type,custom" . "Definition of a user defined type")
    ("typeof" . "typeof.              (line   6")
    ("Typesetting of help and info strings" . "Typesetting of help and info strings")
    ("u" . "u.                   (line   6")
    ("U_D_O" . "U_D_O.               (line   6")
    ("uname" . "system.              (line  37")
    ("unipotent groups" . "orbitparam_lib.      (line  49")
    ("uniquePoint" . "uniquePoint.         (line   6")
    ("unitmat" . "unitmat.             (line   6")
    ("univariate" . "univariate.          (line   6")
    ("univarpoly" . "univarpoly.          (line   6")
    ("Unix installation" . "Unix installation instructions")
    ("unknown syndrome" . "Decoding method based on quadratic equations")
    ("untyped definitions" . "ideal (plural).      (line   6")
    ("updatePairs" . "updatePairs.         (line   6")
    ("UpOneMatrix" . "UpOneMatrix.         (line   6")
    ("UpperMonomials" . "UpperMonomials.      (line   6")
    ("ures_solve" . "ures_solve.          (line   6")
    ("uressolve" . "uressolve.           (line   6")
    ("usage, option" . "option.              (line 198")
    ("UseBertini" . "UseBertini.          (line   6")
    ("User defined types" . "User defined types.  (line   6")
    ("user interface, Emacs" . "Emacs user interface")
    ("V-filtration" . "goodBasis.           (line  22")
    ("valvars" . "valvars.             (line   6")
    ("vandermonde" . "vandermonde.         (line   6")
    ("vanishId" . "vanishId.            (line   6")
    ("var" . "var.                 (line   6")
    ("variables" . "variables.           (line   6")
    ("Variables, indexed" . "Names.               (line   6")
    ("variablesSorted" . "variablesSorted.     (line   6")
    ("variablesStandard" . "variablesStandard.   (line   6")
    ("varNum" . "varNum.              (line   6")
    ("vars2pars" . "vars2pars.           (line   6")
    ("varsigns" . "varsigns.            (line   6")
    ("varstr" . "varstr.              (line   6")
    ("VarToPar" . "VarToPar.            (line   6")
    ("vct2str" . "vct2str.             (line   6")
    ("vdim" . "vdim.                (line   6")
    ("vdim (plural)" . "vdim (plural).       (line   6")
    ("vec2poly" . "vec2poly.            (line   6")
    ("vector" . "vector.              (line   6")
    ("vector declarations" . "vector declarations. (line   6")
    ("vector expressions" . "vector expressions.  (line   6")
    ("vector operations" . "vector operations.   (line   6")
    ("vector related functions" . "vector related functions")
    ("verify" . "verify.              (line   6")
    ("versal" . "versal.              (line   6")
    ("version" . "system.              (line  53")
    ("Version string" . "Version string.      (line   6")
    ("vertices" . "vertices.            (line   6")
    ("vfilt" . "vfilt.               (line   6")
    ("view" . "view.                (line   6")
    ("visual" . "visual.              (line   6")
    ("Visualization" . "Visualization.       (line   6")
    ("visualize" . "visualize.           (line   6")
    ("voice" . "voice.               (line   6")
    ("vwfilt" . "vwfilt.              (line   6")
    ("waitall" . "waitall.             (line   6")
    ("waitfirst" . "waitfirst.           (line   6")
    ("watchdog" . "watchdog.            (line   6")
    ("wedge" . "wedge.               (line   6")
    ("weierstr.lib" . "weierstr_lib.        (line   6")
    ("weierstr_lib" . "weierstr_lib.        (line   6")
    ("Weierstrass" . "Weierstrass.         (line   6")
    ("Weierstrass semigroup" . "brnoeth_lib.         (line  43")
    ("weierstrassForm" . "weierstrassForm.     (line   6")
    ("weierstrDiv" . "weierstrDiv.         (line   6")
    ("weierstrPrep" . "weierstrPrep.        (line   6")
    ("weight" . "weight.              (line   6")
    ("weight filtration" . "goodBasis.           (line  22")
    ("weighted lexicographical ordering" . "Global orderings.    (line  42")
    ("weighted reverse lexicographical ordering" . "Global orderings")
    ("weightedRing" . "weightedRing.        (line   6")
    ("weightKB" . "weightKB.            (line   6")
    ("weightM, option" . "option.              (line 130")
    ("Weyl" . "Weyl.                (line   6")
    ("Weyl algebra" . "dmodvar_lib.         (line  59")
    ("Weyl closure" . "dmodloc_lib.         (line  93")
    ("WeylClosure" . "WeylClosure.         (line   6")
    ("WeylClosure1" . "WeylClosure1.        (line   6")
    ("whichvariable" . "whichvariable.       (line   6")
    ("while" . "while.               (line   6")
    ("Windows installation" . "Windows installation instructions")
    ("WitSet" . "WitSet.              (line   6")
    ("WitSupSet" . "WitSupSet.           (line   6")
    ("WP, global ordering" . "Global orderings.    (line  42")
    ("wp, global ordering" . "Global orderings.    (line  37")
    ("write" . "write.               (line   6")
    ("writeNmzData" . "writeNmzData.        (line   6")
    ("writeNmzPaths" . "writeNmzPaths.       (line   6")
    ("Ws, local ordering" . "Local orderings.     (line  39")
    ("ws, local ordering" . "Local orderings.     (line  33")
    ("WSemigroup" . "WSemigroup.          (line   6")
    ("wUnit" . "wUnit.               (line   6")
    ("wurzel" . "wurzel.              (line   6")
    ("xchange" . "xchange.             (line   6")
    ("xdvi" . "xdvi.                (line   6")
    ("XLsolve" . "XLsolve.             (line   6")
    ("zdd" . "polybori_lib.        (line  94")
    ("zdd2poly" . "zdd2poly.            (line   6")
    ("zero-dimensional" . "qbase.               (line  15")
    ("zerodec" . "zerodec.             (line   6")
    ("zeroMod" . "zeroMod.             (line   6")
    ("zeroOpt" . "zeroOpt.             (line   6")
    ("zeroRadical" . "zeroRadical.         (line   6")
    ("zeroSet" . "zeroSet.             (line   6")
    ("zeroset.lib" . "zeroset_lib.         (line   6")
    ("zeroset_lib" . "zeroset_lib.         (line   6")
    ("zetaDL" . "zetaDL.              (line   6")
    ("ZZsolve" . "ZZsolve.             (line   6")
    ("{" . "Special characters.  (line  11")
    ("||" . "boolean operations.  (line   6")
    ("}" . "Special characters.  (line  11")
    ("~" . "~.                   (line   6")
))
